@@ -40,6 +40,8 @@ gboolean applix_file_probe (GnumFileOpener const *fo, GsfInput *input,
                             FileProbeLevel pl);
 void     applix_file_open (GnumFileOpener const *fo, IOContext *io_context,
                            WorkbookView *wb_view, GsfInput *input);
+void     applix_file_save (GnumFileSaver const *fs, IOContext *io_context,
+			   WorkbookView *wb_view, char const *filename);
 
 gboolean
 applix_file_probe (GnumFileOpener const *fo, GsfInput *input, FileProbeLevel pl)
@@ -47,7 +49,7 @@ applix_file_probe (GnumFileOpener const *fo, GsfInput *input, FileProbeLevel pl)
 	static guint8 const signature[] = "*BEGIN SPREADSHEETS VERSION";
 	guint8 const *header;
 
-	return !gsf_input_seek (input, 0, GSF_SEEK_SET) &&
+	return !gsf_input_seek (input, 0, G_SEEK_SET) &&
 		NULL != (header = gsf_input_read (input, sizeof (signature)-1, NULL)) &&
 		0 == memcmp (header, signature, sizeof (signature)-1);
 }
