@@ -5,8 +5,22 @@
  *   Elliot Lee <sopwith@redhat.com>     All initial work.
  *   Morten Welinder <terra@diku.dk>     Port to new plugin framework.
  *                                         Cleanup.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include <gnumeric.h>
 #include <glib.h>
 #include <math.h>
@@ -18,7 +32,6 @@
 #include "value.h"
 #include "plugin-util.h"
 #include "module-plugin-defs.h"
-#include <libgnome/gnome-i18n.h>
 
 GNUMERIC_MODULE_PLUGIN_INFO_DECL;
 
@@ -289,228 +302,269 @@ func_opt_bs_vega (FunctionEvalInfo *ei, Value *argv[])
 
 static const char *help_opt_bs_call = {
 	N_("@FUNCTION=opt_bs_call\n"
-	   "@SYNTAX=opt_bs_call(strike,price,volatility,days_to_maturity,rate)\n"
+	   "@SYNTAX=OPT_BS_CALL(strike,price,volatility,days_to_maturity,"
+	   "rate)\n"
 	   "@DESCRIPTION="
-	   "Uses the Black-Scholes model to calculate the price of a European "
-	   "call option struck at @strike on an asset with price @price.  "
-	   "@volatility is the annualized volatility, in percent, of the "
-	   "asset for the period through to the exercise date.  "
+	   "OPT_BS_CALL uses the Black-Scholes model to calculate the price of "
+	   "a European call option struck at @strike on an asset with price "
+	   "@price.\n"
+	   "\n"
+	   "@volatility is the annualized volatility, in percent, of "
+	   "the asset for the period through to the exercise date.  "
 	   "@days_to_maturity the number of days to exercise, and @rate is "
 	   "the risk-free interest rate to the exercise date, in percent.\n"
-	   "The returned value will be expressed in the same units as "
-	   "@strike and @price."
+	   "\n"
+	   "* The returned value will be expressed in the same units as "
+	   "@strike and @price.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "\n"
-	   "@SEEALSO=opt_bs_put, opt_bs_call_delta, opt_bs_put_delta "
-	   "opt_bs_call_rho, opt_bs_put_rho, opt_bs_call_theta, "
-	   "opt_bs_put_theta, opt_bs_vega, opt_bs_gamma")
+	   "@SEEALSO=OPT_BS_PUT, OPT_BS_CALL_DELTA, OPT_BS_PUT_DELTA, "
+	   "OPT_BS_CALL_RHO, OPT_BS_PUT_RHO, OPT_BS_CALL_THETA, "
+	   "OPT_BS_PUT_THETA, OPT_BS_VEGA, OPT_BS_GAMMA")
 };
 
 static const char *help_opt_bs_put = {
-	N_("@FUNCTION=opt_bs_put\n"
-	   "@SYNTAX=opt_bs_put(strike,price,volatility,days_to_maturity,rate)\n"
+	N_("@FUNCTION=OPT_BS_PUT\n"
+	   "@SYNTAX=OPT_BS_PUT(strike,price,volatility,days_to_maturity,rate)\n"
 	   "@DESCRIPTION="
-	   "Uses the Black-Scholes model to calculate the price of a European "
-	   "put option struck at @strike on an asset with price @price.  "
-	   "@volatility is the annualized volatility, in percent, of the "
-	   "asset for the period through to the exercise date.  "
+	   "OPT_BS_PUT uses the Black-Scholes model to calculate the price of "
+	   "a European put option struck at @strike on an asset with price "
+	   "@price.\n"
+	   "\n"
+	   "@volatility is the annualized volatility, in percent, of "
+	   "the asset for the period through to the exercise date.  "
 	   "@days_to_maturity the number of days to exercise, and @rate is "
 	   "the risk-free interest rate to the exercise date, in percent.\n"
-	   "The returned value will be expressed in the same units as "
-	   "@strike and @price."
+	   "\n"
+	   "* The returned value will be expressed in the same units as "
+	   "@strike and @price.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "\n"
-	   "@SEEALSO=opt_bs_call, opt_bs_call_delta, opt_bs_put_delta "
-	   "opt_bs_call_rho, opt_bs_put_rho, opt_bs_call_theta, "
-	   "opt_bs_put_theta, opt_bs_vega, opt_bs_gamma")
+	   "@SEEALSO=OPT_BS_CALL, OPT_BS_CALL_DELTA, OPT_BS_PUT_DELTA, "
+	   "OPT_BS_CALL_RHO, OPT_BS_PUT_RHO, OPT_BS_CALL_THETA, "
+	   "OPT_BS_PUT_THETA, OPT_BS_VEGA, OPT_BS_GAMMA")
 };
 
 static const char *help_opt_bs_call_delta = {
-	N_("@FUNCTION=opt_bs_call_delta\n"
-	   "@SYNTAX=opt_bs_call_delta(strike,price,volatility,days_to_maturity,rate)\n"
+	N_("@FUNCTION=OPT_BS_CALL_DELTA\n"
+	   "@SYNTAX=OPT_BS_CALL_DELTA(strike,price,volatility,days_to_maturity,"
+	   "rate)\n"
 	   "@DESCRIPTION="
-	   "Uses the Black-Scholes model to calculate the \"delta\" of a "
-	   "European call option struck at @strike on an asset with price "
-	   "@price.\n"
+	   "OPT_BS_CALL_DELTA uses the Black-Scholes model to calculate the "
+	   "\"delta\" of a European call option struck at @strike on an "
+	   "asset with price @price.\n"
+	   "\n"
 	   "(The delta of an option is the rate of change of its price with "
 	   "respect to the price of the underlying asset.)\n"
+	   "\n"
 	   "@volatility is the annualized volatility, in percent, of the "
 	   "asset for the period through to the exercise date.  "
 	   "@days_to_maturity the number of days to exercise, and @rate is "
 	   "the risk-free interest rate to the exercise date, in percent.\n"
-	   "The returned value will be expressed as the rate of change of "
+	   "\n"
+	   "* The returned value will be expressed as the rate of change of "
 	   "option value per unit change in @price."
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "\n"
-	   "@SEEALSO=opt_bs_call, opt_bs_put, opt_bs_put_delta "
-	   "opt_bs_call_rho, opt_bs_put_rho, opt_bs_call_theta, "
-	   "opt_bs_put_theta, opt_bs_vega, opt_bs_gamma")
+	   "@SEEALSO=OPT_BS_CALL, OPT_BS_PUT, OPT_BS_PUT_DELTA, "
+	   "OPT_BS_CALL_RHO, OPT_BS_PUT_RHO, OPT_BS_CALL_THETA, "
+	   "OPT_BS_PUT_THETA, OPT_BS_VEGA, OPT_BS_GAMMA")
 };
 
 static const char *help_opt_bs_put_delta = {
-	N_("@FUNCTION=opt_bs_put_delta\n"
-	   "@SYNTAX=opt_bs_put_delta(strike,price,volatility,days_to_maturity,rate)\n"
+	N_("@FUNCTION=OPT_BS_PUT_DELTA\n"
+	   "@SYNTAX=OPT_BS_PUT_DELTA(strike,price,volatility,days_to_maturity,"
+	   "rate)\n"
 	   "@DESCRIPTION="
-	   "Uses the Black-Scholes model to calculate the \"delta\" of a "
-	   "European put option struck at @strike on an asset with price "
-	   "@price.\n"
+	   "OPT_BS_PUT_DELTA uses the Black-Scholes model to calculate the "
+	   "\"delta\" of a European put option struck at @strike on an asset "
+	   "with price @price.\n"
+	   "\n"
 	   "(The delta of an option is the rate of change of its price with "
 	   "respect to the price of the underlying asset.)\n"
+	   "\n"
 	   "@volatility is the annualized volatility, in percent, of the "
 	   "asset for the period through to the exercise date.  "
 	   "@days_to_maturity the number of days to exercise, and @rate is "
 	   "the risk-free interest rate to the exercise date, in percent.\n"
-	   "The returned value will be expressed as the rate of change of "
+	   "\n"
+	   "* The returned value will be expressed as the rate of change of "
 	   "option value per unit change in @price."
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "\n"
-	   "@SEEALSO=opt_bs_call, opt_bs_put, opt_bs_call_delta "
-	   "opt_bs_call_rho, opt_bs_put_rho, opt_bs_call_theta, "
-	   "opt_bs_put_theta, opt_bs_vega, opt_bs_gamma")
+	   "@SEEALSO=OPT_BS_CALL, OPT_BS_PUT, OPT_BS_CALL_DELTA, "
+	   "OPT_BS_CALL_RHO, OPT_BS_PUT_RHO, OPT_BS_CALL_THETA, "
+	   "OPT_BS_PUT_THETA, OPT_BS_VEGA, OPT_BS_GAMMA")
 };
 
 static const char *help_opt_bs_call_rho = {
         /* xgettext:no-c-format */
-	N_("@FUNCTION=opt_bs_call_rho\n"
-	   "@SYNTAX=opt_bs_call_rho(strike,price,volatility,days_to_maturity,rate)\n"
+	N_("@FUNCTION=OPT_BS_CALL_RHO\n"
+	   "@SYNTAX=OPT_BS_CALL_RHO(strike,price,volatility,days_to_maturity,"
+	   "rate)\n"
 	   "@DESCRIPTION="
-	   "Uses the Black-Scholes model to calculate the \"rho\" of a "
-	   "European call option struck at @strike on an asset with price "
-	   "@price.\n"
+	   "OPT_BS_CALL_RHO uses the Black-Scholes model to calculate the "
+	   "\"rho\" of a European call option struck at @strike on an asset "
+	   "with price @price.\n"
+	   "\n"
 	   "(The rho of an option is the rate of change of its price with "
 	   "respect to the risk free interest rate.)\n"
+	   "\n"
 	   "@volatility is the annualized volatility, in percent, of the "
 	   "asset for the period through to the exercise date.  "
 	   "@days_to_maturity the number of days to exercise, and @rate is "
 	   "the risk-free interest rate to the exercise date, in percent.\n"
-	   "The returned value will be expressed as the rate of change of "
+	   "\n"
+	   "* The returned value will be expressed as the rate of change of "
 	   "option value, per 100% change in @rate."
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "\n"
-	   "@SEEALSO=opt_bs_call, opt_bs_put, opt_bs_call_delta, "
-	   "opt_bs_put_delta, opt_bs_put_rho, opt_bs_call_theta, "
-	   "opt_bs_put_theta, opt_bs_vega, opt_bs_gamma")
+	   "@SEEALSO=OPT_BS_CALL, OPT_BS_PUT, OPT_BS_CALL_DELTA, "
+	   "OPT_BS_PUT_DELTA, OPT_BS_PUT_RHO, OPT_BS_CALL_THETA, "
+	   "OPT_BS_PUT_THETA, OPT_BS_VEGA, OPT_BS_GAMMA")
 };
 
 static const char *help_opt_bs_put_rho = {
         /* xgettext:no-c-format */
-	N_("@FUNCTION=opt_bs_put_rho\n"
-	   "@SYNTAX=opt_bs_put_rho(strike,price,volatility,days_to_maturity,rate)\n"
+	N_("@FUNCTION=OPT_BS_PUT_RHO\n"
+	   "@SYNTAX=OPT_BS_PUT_RHO(strike,price,volatility,days_to_maturity,"
+	   "rate)\n"
 	   "@DESCRIPTION="
-	   "Uses the Black-Scholes model to calculate the \"rho\" of a "
-	   "European put option struck at @strike on an asset with price "
-	   "@price.\n"
+	   "OPT_BS_PUT_RHO uses the Black-Scholes model to calculate the "
+	   "\"rho\" of a European put option struck at @strike on an asset "
+	   "with price @price.\n"
+	   "\n"
 	   "(The rho of an option is the rate of change of its price with "
 	   "respect to the risk free interest rate.)\n"
+	   "\n"
 	   "@volatility is the annualized volatility, in percent, of the "
 	   "asset for the period through to the exercise date.  "
 	   "@days_to_maturity the number of days to exercise, and @rate is "
 	   "the risk-free interest rate to the exercise date, in percent.\n"
-	   "The returned value will be expressed as the rate of change of "
+	   "\n"
+	   "* The returned value will be expressed as the rate of change of "
 	   "option value, per 100% change in @rate."
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "\n"
-	   "@SEEALSO=opt_bs_call, opt_bs_put, opt_bs_call_delta "
-	   "opt_bs_put_delta, opt_bs_call_rho, opt_bs_call_theta, "
-	   "opt_bs_put_theta, opt_bs_vega, opt_bs_gamma")
+	   "@SEEALSO=OPT_BS_CALL, OPT_BS_PUT, OPT_BS_CALL_DELTA, "
+	   "OPT_BS_PUT_DELTA, OPT_BS_CALL_RHO, OPT_BS_CALL_THETA, "
+	   "OPT_BS_PUT_THETA, OPT_BS_VEGA, OPT_BS_GAMMA")
 };
 
 static const char *help_opt_bs_call_theta = {
-	N_("@FUNCTION=opt_bs_call_theta\n"
-	   "@SYNTAX=opt_bs_call_theta(strike,price,volatility,days_to_maturity,rate)\n"
+	N_("@FUNCTION=OPT_BS_CALL_THETA\n"
+	   "@SYNTAX=OPT_BS_CALL_THETA(strike,price,volatility,days_to_maturity,"
+	   "rate)\n"
 	   "@DESCRIPTION="
-	   "Uses the Black-Scholes model to calculate the \"theta\" of a "
-	   "European call option struck at @strike on an asset with price "
-	   "@price.\n"
+	   "OPT_BS_CALL_THETA uses the Black-Scholes model to calculate the "
+	   "\"theta\" of a European call option struck at @strike on an asset "
+	   "with price @price.\n"
+	   "\n"
 	   "(The theta of an option is the rate of change of its price with "
 	   "respect to time to expiry.)\n"
+	   "\n"
 	   "@volatility is the annualized volatility, in percent, of the "
 	   "asset for the period through to the exercise date.  "
 	   "@days_to_maturity the number of days to exercise, and @rate is "
 	   "the risk-free interest rate to the exercise date, in percent.\n"
-	   "The returned value will be expressed as minus the rate of change "
+	   "\n"
+	   "* The returned value will be expressed as minus the rate of change "
 	   "of option value, per 365.25 days."
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "\n"
-	   "@SEEALSO=opt_bs_call, opt_bs_put, opt_bs_call_delta, "
-	   "opt_bs_put_delta, opt_bs_call_rho, opt_bs_put_rho, "
-	   "opt_bs_put_theta, opt_bs_vega, opt_bs_gamma")
+	   "@SEEALSO=OPT_BS_CALL, OPT_BS_PUT, OPT_BS_CALL_DELTA, "
+	   "OPT_BS_PUT_DELTA, OPT_BS_CALL_RHO, OPT_BS_PUT_RHO, "
+	   "OPT_BS_PUT_THETA, OPT_BS_VEGA, OPT_BS_GAMMA")
 };
 
 static const char *help_opt_bs_put_theta = {
-	N_("@FUNCTION=opt_bs_put_theta\n"
-	   "@SYNTAX=opt_bs_put_theta(strike,price,volatility,days_to_maturity,rate)\n"
+	N_("@FUNCTION=OPT_BS_PUT_THETA\n"
+	   "@SYNTAX=OPT_BS_PUT_THETA(strike,price,volatility,days_to_maturity,"
+	   "rate)\n"
 	   "@DESCRIPTION="
-	   "Uses the Black-Scholes model to calculate the \"theta\" of a "
-	   "European put option struck at @strike on an asset with price "
-	   "@price.\n"
+	   "OPT_BS_PUT_THETA uses the Black-Scholes model to calculate the "
+	   "\"theta\" of a European put option struck at @strike on an asset "
+	   "with price @price.\n"
+	   "\n"
 	   "(The theta of an option is the rate of change of its price with "
 	   "respect to time to expiry.)\n"
+	   "\n"
 	   "@volatility is the annualized volatility, in percent, of the "
 	   "asset for the period through to the exercise date.  "
 	   "@days_to_maturity the number of days to exercise, and @rate is "
 	   "the risk-free interest rate to the exercise date, in percent.\n"
-	   "The returned value will be expressed as minus the rate of change "
+	   "\n"
+	   "* The returned value will be expressed as minus the rate of change "
 	   "of option value, per 365.25 days."
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "\n"
-	   "@SEEALSO=opt_bs_call, opt_bs_put, opt_bs_call_delta "
-	   "opt_bs_put_delta, opt_bs_call_rho, opt_bs_put_rho, "
-	   "opt_bs_call_theta, opt_bs_vega, opt_bs_gamma")
+	   "@SEEALSO=OPT_BS_CALL, OPT_BS_PUT, OPT_BS_CALL_DELTA, "
+	   "OPT_BS_PUT_DELTA, OPT_BS_CALL_RHO, OPT_BS_PUT_RHO, "
+	   "OPT_BS_CALL_THETA, OPT_BS_VEGA, OPT_BS_GAMMA")
 };
 
 static const char *help_opt_bs_gamma = {
-	N_("@FUNCTION=opt_bs_gamma\n"
-	   "@SYNTAX=opt_bs_gamma(strike,price,volatility,days_to_maturity,rate)\n"
+	N_("@FUNCTION=OPT_BS_GAMMA\n"
+	   "@SYNTAX=OPT_BS_GAMMA(strike,price,volatility,days_to_maturity,"
+	   "rate)\n"
 	   "@DESCRIPTION="
-	   "Uses the Black-Scholes model to calculate the \"gamma\" of a "
-	   "European option struck at @strike on an asset with price @price.\n"
+	   "OPT_BS_GAMMA uses the Black-Scholes model to calculate the "
+	   "\"gamma\" of a European option struck at @strike on an asset "
+	   "with price @price.\n"
+	   "\n"
 	   "(The gamma of an option is the second derivative of its price "
 	   "with respect to the price of the underlying asset, and is the "
 	   "same for calls and puts.)\n"
+	   "\n"
 	   "@volatility is the annualized volatility, in percent, of the "
 	   "asset for the period through to the exercise date.  "
 	   "@days_to_maturity the number of days to exercise, and @rate is "
 	   "the risk-free interest rate to the exercise date, in percent.\n"
-	   "The returned value will be expressed as the rate of change "
+	   "\n"
+	   "* The returned value will be expressed as the rate of change "
 	   "of delta per unit change in @price."
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "\n"
-	   "@SEEALSO=opt_bs_call, opt_bs_put, opt_bs_call_delta "
-	   "opt_bs_put_delta, opt_bs_call_rho, opt_bs_put_rho, "
-	   "opt_bs_call_theta, opt_bs_put_rho, opt_bs_vega")
+	   "@SEEALSO=OPT_BS_CALL, OPT_BS_PUT, OPT_BS_CALL_DELTA, "
+	   "OPT_BS_PUT_DELTA, OPT_BS_CALL_RHO, OPT_BS_PUT_RHO, "
+	   "OPT_BS_CALL_THETA, OPT_BS_PUT_RHO, OPT_BS_VEGA")
 };
 
 static const char *help_opt_bs_vega = {
         /* xgettext:no-c-format */
-	N_("@FUNCTION=opt_bs_vega\n"
-	   "@SYNTAX=opt_bs_bega(strike,price,volatility,days_to_maturity,rate)\n"
+	N_("@FUNCTION=OPT_BS_VEGA\n"
+	   "@SYNTAX=OPT_BS_VEGA(strike,price,volatility,days_to_maturity,"
+	   "rate)\n"
 	   "@DESCRIPTION="
-	   "Uses the Black-Scholes model to calculate the \"vega\" of a "
-	   "European option struck at @strike on an asset with price @price.\n"
+	   "OPT_BS_VEGA uses the Black-Scholes model to calculate the "
+	   "\"vega\" of a European option struck at @strike on an asset "
+	   "with price @price.\n"
+	   "\n"
 	   "(The vega of an option is the rate of change of its price with "
 	   "respect to volatility, and is the same for calls and puts.)\n"
+	   "\n"
 	   "@volatility is the annualized volatility, in percent, of the "
 	   "asset for the period through to the exercise date.  "
 	   "@days_to_maturity the number of days to exercise, and @rate is "
 	   "the risk-free interest rate to the exercise date, in percent.\n"
-	   "The returned value will be expressed as the rate of change "
+	   "\n"
+	   "* The returned value will be expressed as the rate of change "
 	   "of option value, per 100% volatilty."
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "\n"
-	   "@SEEALSO=opt_bs_call, opt_bs_put, opt_bs_call_delta "
-	   "opt_bs_put_delta, opt_bs_call_rho, opt_bs_put_rho, "
-	   "opt_bs_call_theta, opt_bs_put_rho, opt_bs_gamma")
+	   "@SEEALSO=OPT_BS_CALL, OPT_BS_PUT, OPT_BS_CALL_DELTA, "
+	   "OPT_BS_PUT_DELTA, OPT_BS_CALL_RHO, OPT_BS_PUT_RHO, "
+	   "OPT_BS_CALL_THETA, OPT_BS_PUT_RHO, OPT_BS_GAMMA")
 };
 
 const ModulePluginFunctionInfo derivatives_functions[] = {
