@@ -14,6 +14,7 @@
  * FIXME: Check for errors and propagate upward. We've only started.
  */
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include <gnumeric.h>
 #include "ms-formula-write.h"
 #include "boot.h"
@@ -48,8 +49,8 @@
 #include <gsf/gsf-utils.h>
 #include <gsf/gsf-output.h>
 #include <gsf/gsf-outfile.h>
+#include <gsf/gsf-msole-metadata.h>
 
-#include <libgnome/gnome-i18n.h>
 #include <ctype.h>
 #include <math.h>
 
@@ -62,7 +63,7 @@
 
 #define N_ELEMENTS_BETWEEN_PROGRESS_UPDATES   20
 
-static excel_iconv_t current_workbook_iconv = NULL;
+static GIConv current_workbook_iconv = NULL;
 
 static guint style_color_to_rgb888 (const StyleColor *c);
 static gint  palette_get_index (ExcelWorkbook *wb, guint c);
@@ -84,7 +85,9 @@ biff_convert_text (char **buf, const char *txt, MsBiffVersion ver)
 		wchar_t* wcbuf;
 		guint16 *outbuf;
 		len = mbstowcs(NULL, txt, 0);
+
 		g_return_val_if_fail (len > 0, 0);
+
 		wcbuf = g_new(wchar_t, len + 1);
 		mbstowcs(wcbuf,txt,len + 1);
 
@@ -98,15 +101,16 @@ biff_convert_text (char **buf, const char *txt, MsBiffVersion ver)
 	} else {
 		size_t inbufleft = len, outbufleft = len*8;
 		char *outbufptr;
-		char const * inbufptr = txt;
+		char const *inbufptr = txt;
 
 		*buf = g_new(char, outbufleft);
 		outbufptr = *buf;
 
-		excel_iconv (current_workbook_iconv, &inbufptr, &inbufleft, 
-			     &outbufptr, &outbufleft);
+		g_iconv (current_workbook_iconv,
+			 (char **)&inbufptr, &inbufleft, 
+			 &outbufptr, &outbufleft);
 		len = outbufptr - *buf;
-	};
+	}
 	return len;
 }
 
@@ -405,7 +409,7 @@ excel_write_externsheets (BiffPut *bp, ExcelWorkbook *wb, ExcelSheet *ignore)
 
 		if (esheet == ignore) continue;
 
-		len = biff_convert_text (&buf, esheet->gnum_sheet->name_quoted, wb->ver);
+		len = biff_convert_text (&buf, esheet->gnum_sheet->name_unquoted, wb->ver);
 		ms_biff_put_var_next (bp, BIFF_EXTERNSHEET);
 		GSF_LE_SET_GUINT8(data, len);
 		GSF_LE_SET_GUINT8(data + 1, 3); /* Magic */
@@ -464,7 +468,7 @@ excel_write_WINDOW2 (BiffPut *bp, MsBiffVersion ver, ExcelSheet *esheet)
 	guint16 options = 0x0A0;
 	guint8 *data;
 	CellPos top_left;
-	Sheet  const *sheet = esheet->gnum_sheet;
+	Sheet const *sheet = esheet->gnum_sheet;
 	SheetView const *sv = sheet_get_view (sheet, esheet->wb->gnum_wb_view);
 	StyleColor *sheet_auto   = sheet_style_get_auto_pattern_color (sheet);
 	StyleColor *default_auto = style_color_auto_pattern ();
@@ -812,14 +816,14 @@ biff_boundsheet_write_last (GsfOutput *output, guint32 pos,
 			    unsigned streamPos)
 {
 	guint8  data[4];
-	unsigned oldpos;
+	gsf_off_t oldpos;
 	g_return_if_fail (output);
 
 	oldpos = gsf_output_tell (output);
-	gsf_output_seek (output, pos+4, GSF_SEEK_SET);
+	gsf_output_seek (output, pos+4, G_SEEK_SET);
 	GSF_LE_SET_GUINT32 (data, streamPos);
 	gsf_output_write (output, 4, data);
-	gsf_output_seek (output, oldpos, GSF_SEEK_SET);
+	gsf_output_seek (output, oldpos, G_SEEK_SET);
 }
 
 /**
@@ -3002,7 +3006,7 @@ write_sheet_head (BiffPut *bp, ExcelSheet *esheet)
 }
 
 static void
-excel_write_SELECTION (ExcelSheet *esheet, BiffPut *bp)
+excel_write_SELECTION (BiffPut *bp, ExcelSheet *esheet)
 {
 	SheetView const *sv = sheet_get_view (esheet->gnum_sheet,
 		esheet->wb->gnum_wb_view);
@@ -3011,7 +3015,7 @@ excel_write_SELECTION (ExcelSheet *esheet, BiffPut *bp)
 	guint8 *data;
 
 	data = ms_biff_put_len_next (bp, BIFF_SELECTION, 15);
-	GSF_LE_SET_GUINT8  (data +  0, 0);	/* pane 0 */
+	GSF_LE_SET_GUINT8  (data +  0, 3); /* no split == pane 3 ? */
 	GSF_LE_SET_GUINT16 (data +  1, sv->edit_pos.row);
 	GSF_LE_SET_GUINT16 (data +  3, sv->edit_pos.col);
 	GSF_LE_SET_GUINT16 (data +  5, 0); /* our edit_pos is in 1st range */
@@ -3047,7 +3051,7 @@ excel_write_sheet_tail (IOContext *context, BiffPut *bp, ExcelSheet *esheet)
 	GSF_LE_SET_GUINT16 (data + 2, denom);
 	ms_biff_put_commit (bp);
 
-	excel_write_SELECTION (esheet, bp);
+	excel_write_SELECTION (bp, esheet);
 	excel_write_MERGECELLS (bp, ver, esheet);
 
 /* See: S59D90.HTM: Global Column Widths...  not cricual.
@@ -3067,7 +3071,7 @@ static void
 write_index (GsfOutput *output, ExcelSheet *esheet, unsigned pos)
 {
 	guint8  data[4];
-	unsigned oldpos;
+	gsf_off_t oldpos;
 	guint lp;
 
 	g_return_if_fail (output);
@@ -3075,9 +3079,9 @@ write_index (GsfOutput *output, ExcelSheet *esheet, unsigned pos)
 
 	oldpos = gsf_output_tell (output);
 	if (esheet->wb->ver >= MS_BIFF_V8)
-		gsf_output_seek (output, pos+4+16, GSF_SEEK_SET);
+		gsf_output_seek (output, pos+4+16, G_SEEK_SET);
 	else
-		gsf_output_seek (output, pos+4+12, GSF_SEEK_SET);
+		gsf_output_seek (output, pos+4+12, G_SEEK_SET);
 
 	for (lp = 0; lp < esheet->dbcells->len; lp++) {
 		unsigned pos = g_array_index (esheet->dbcells, unsigned, lp);
@@ -3089,7 +3093,7 @@ write_index (GsfOutput *output, ExcelSheet *esheet, unsigned pos)
 		gsf_output_write (output, 4, data);
 	}
 
-	gsf_output_seek (output, oldpos, GSF_SEEK_SET);
+	gsf_output_seek (output, oldpos, G_SEEK_SET);
 }
 
 /* See: S59DDB.HTM */
@@ -3508,7 +3512,7 @@ write_workbook (IOContext *context, BiffPut *bp, ExcelWorkbook *wb, MsBiffVersio
 					    s->streamPos);
 	}
 	/* End Finalised workbook */
-	excel_iconv_close (current_workbook_iconv);
+	gnm_iconv_close (current_workbook_iconv);
 	current_workbook_iconv = NULL;
 }
 
@@ -3590,6 +3594,18 @@ ms_excel_write_workbook (IOContext *context, GsfOutfile *outfile, void *state,
 	gsf_output_close (content);
 	g_object_unref (G_OBJECT (content));
 
+	content = gsf_outfile_new_child (outfile,
+		"\05DocumentSummaryInformation", FALSE);
+	gsf_msole_metadata_write (content, TRUE, NULL);
+	gsf_output_close (content);
+	g_object_unref (G_OBJECT (content));
+
+	content = gsf_outfile_new_child (outfile,
+		"\05SummaryInformation", FALSE);
+	gsf_msole_metadata_write (content, FALSE, NULL);
+	gsf_output_close (content);
+	g_object_unref (G_OBJECT (content));
+
 	d (0, fflush (stdout););
 }
 
