@@ -25,15 +25,18 @@
 
 #include <gnumeric-config.h>
 #include <gnumeric.h>
-#include <expr.h>
 
 #include "boot.h"
 #include "ms-obj.h"
 #include "ms-chart.h"
 #include "ms-escher.h"
-#include "parse-util.h"
-#include "sheet-object-widget.h"
-#include "sheet-object-graphic.h"
+
+#include <expr.h>
+#include <parse-util.h>
+#include <sheet-object-widget.h>
+#include <sheet-object-graphic.h>
+
+#include <gsf/gsf-utils.h>
 
 #define GR_END                0x00
 #define GR_MACRO              0x04
@@ -56,7 +59,7 @@
 #define GR_COMMON_OBJ_DATA    0x15
 
 MSObjAttr *
-ms_object_attr_new_flag (MSObjAttrID id)
+ms_obj_attr_new_flag (MSObjAttrID id)
 {
 	MSObjAttr *res = g_new (MSObjAttr, 1);
 
@@ -67,7 +70,7 @@ ms_object_attr_new_flag (MSObjAttrID id)
 }
 
 MSObjAttr *
-ms_object_attr_new_uint (MSObjAttrID id, guint32 val)
+ms_obj_attr_new_uint (MSObjAttrID id, guint32 val)
 {
 	MSObjAttr *res = g_new (MSObjAttr, 1);
 
@@ -79,7 +82,7 @@ ms_object_attr_new_uint (MSObjAttrID id, guint32 val)
 	return res;
 }
 MSObjAttr *
-ms_object_attr_new_ptr (MSObjAttrID id, gpointer val)
+ms_obj_attr_new_ptr (MSObjAttrID id, gpointer val)
 {
 	MSObjAttr *res = g_new (MSObjAttr, 1);
 
@@ -92,7 +95,20 @@ ms_object_attr_new_ptr (MSObjAttrID id, gpointer val)
 }
 
 MSObjAttr *
-ms_object_attr_new_expr (MSObjAttrID id, GnmExpr const *expr)
+ms_obj_attr_new_array (MSObjAttrID id, GArray *array)
+{
+	MSObjAttr *res = g_new (MSObjAttr, 1);
+
+	g_return_val_if_fail ((id & MS_OBJ_ATTR_MASK) == MS_OBJ_ATTR_IS_GARRAY_MASK, NULL);
+
+	/* be anal about constness */
+	*((MSObjAttrID *)&(res->id)) = id;
+	res->v.v_array = array;
+	return res;
+}
+
+MSObjAttr *
+ms_obj_attr_new_expr (MSObjAttrID id, GnmExpr const *expr)
 {
 	MSObjAttr *res = g_new (MSObjAttr, 1);
 
@@ -105,71 +121,91 @@ ms_object_attr_new_expr (MSObjAttrID id, GnmExpr const *expr)
 }
 
 guint32
-ms_object_attr_get_uint (MSObj *obj, MSObjAttrID id, guint32 default_value)
+ms_obj_attr_get_uint (MSObj *obj, MSObjAttrID id, guint32 default_value)
 {
 	MSObjAttr *attr;
 
 	g_return_val_if_fail (obj != NULL, default_value);
 	g_return_val_if_fail (id & MS_OBJ_ATTR_IS_INT_MASK, default_value);
 
-	attr = ms_object_attr_bag_lookup (obj->attrs, id);
+	attr = ms_obj_attr_bag_lookup (obj->attrs, id);
 	if (attr == NULL)
 		return default_value;
 	return attr->v.v_uint;
 }
 
 gint32
-ms_object_attr_get_int  (MSObj *obj, MSObjAttrID id, gint32 default_value)
+ms_obj_attr_get_int  (MSObj *obj, MSObjAttrID id, gint32 default_value)
 {
 	MSObjAttr *attr;
 
 	g_return_val_if_fail (obj != NULL, default_value);
 	g_return_val_if_fail (id & MS_OBJ_ATTR_IS_INT_MASK, default_value);
 
-	attr = ms_object_attr_bag_lookup (obj->attrs, id);
+	attr = ms_obj_attr_bag_lookup (obj->attrs, id);
 	if (attr == NULL)
 		return default_value;
 	return attr->v.v_int;
 }
 
 gpointer
-ms_object_attr_get_ptr  (MSObj *obj, MSObjAttrID id, gpointer default_value)
+ms_obj_attr_get_ptr  (MSObj *obj, MSObjAttrID id, gpointer default_value)
 {
 	MSObjAttr *attr;
 
 	g_return_val_if_fail (obj != NULL, default_value);
 	g_return_val_if_fail (id & MS_OBJ_ATTR_IS_PTR_MASK, default_value);
 
-	attr = ms_object_attr_bag_lookup (obj->attrs, id);
+	attr = ms_obj_attr_bag_lookup (obj->attrs, id);
 	if (attr == NULL)
 		return default_value;
 	return attr->v.v_ptr;
 }
 
+GArray *
+ms_obj_attr_get_array (MSObj *obj, MSObjAttrID id, GArray *default_value)
+{
+	MSObjAttr *attr;
+
+	g_return_val_if_fail (obj != NULL, default_value);
+	g_return_val_if_fail (id & MS_OBJ_ATTR_IS_GARRAY_MASK, default_value);
+
+	attr = ms_obj_attr_bag_lookup (obj->attrs, id);
+	if (attr == NULL)
+		return default_value;
+	return attr->v.v_array;
+}
+
 GnmExpr const *
-ms_object_attr_get_expr (MSObj *obj, MSObjAttrID id, GnmExpr const *default_value)
+ms_obj_attr_get_expr (MSObj *obj, MSObjAttrID id, GnmExpr const *default_value)
 {
 	MSObjAttr *attr;
 
 	g_return_val_if_fail (obj != NULL, default_value);
 	g_return_val_if_fail (id & MS_OBJ_ATTR_IS_EXPR_MASK, default_value);
 
-	attr = ms_object_attr_bag_lookup (obj->attrs, id);
+	attr = ms_obj_attr_bag_lookup (obj->attrs, id);
 	if (attr == NULL)
 		return default_value;
 	return attr->v.v_expr;
 }
 
 static void
-ms_object_attr_destroy (MSObjAttr *attr)
+ms_obj_attr_destroy (MSObjAttr *attr)
 {
 	if (attr != NULL) {
 		if ((attr->id & MS_OBJ_ATTR_IS_PTR_MASK) &&
 		    attr->v.v_ptr != NULL) {
 			g_free (attr->v.v_ptr);
+			attr->v.v_ptr = NULL;
+		} else if ((attr->id & MS_OBJ_ATTR_IS_GARRAY_MASK) &&
+			   attr->v.v_array != NULL) {
+			g_array_free (attr->v.v_array, TRUE);
+			attr->v.v_array = NULL;
 		} else if ((attr->id & MS_OBJ_ATTR_IS_EXPR_MASK) &&
-		    attr->v.v_expr != NULL) {
+			   attr->v.v_expr != NULL) {
 			gnm_expr_unref (attr->v.v_expr);
+			attr->v.v_expr = NULL;
 		}
 		g_free (attr);
 	}
@@ -188,35 +224,35 @@ cb_ms_obj_attr_cmp (gconstpointer a, gconstpointer b)
 }
 
 MSObjAttrBag *
-ms_object_attr_bag_new (void)
+ms_obj_attr_bag_new (void)
 {
 	return g_hash_table_new (cb_ms_obj_attr_hash, cb_ms_obj_attr_cmp);
 }
 
 static void
-cb_ms_object_attr_destroy (gpointer key, gpointer value, gpointer ignored)
+cb_ms_obj_attr_destroy (gpointer key, gpointer value, gpointer ignored)
 {
-	ms_object_attr_destroy (value);
+	ms_obj_attr_destroy (value);
 }
 void
-ms_object_attr_bag_destroy (MSObjAttrBag *attrs)
+ms_obj_attr_bag_destroy (MSObjAttrBag *attrs)
 {
 	if (attrs != NULL) {
-		g_hash_table_foreach (attrs, cb_ms_object_attr_destroy, NULL);
+		g_hash_table_foreach (attrs, cb_ms_obj_attr_destroy, NULL);
 		g_hash_table_destroy (attrs);
 	}
 }
 
 
 void
-ms_object_attr_bag_insert (MSObjAttrBag *attrs, MSObjAttr *attr)
+ms_obj_attr_bag_insert (MSObjAttrBag *attrs, MSObjAttr *attr)
 {
 	g_return_if_fail (!g_hash_table_lookup (attrs, attr));
 	g_hash_table_insert (attrs, attr, attr);
 }
 
 MSObjAttr *
-ms_object_attr_bag_lookup (MSObjAttrBag *attrs, MSObjAttrID id)
+ms_obj_attr_bag_lookup (MSObjAttrBag *attrs, MSObjAttrID id)
 {
 	if (attrs != NULL) {
 		MSObjAttr attr;
@@ -228,6 +264,22 @@ ms_object_attr_bag_lookup (MSObjAttrBag *attrs, MSObjAttrID id)
 
 /********************************************************************************/
 
+MSObj *
+ms_obj_new (MSObjAttrBag *attrs)
+{
+	MSObj *obj = g_new0 (MSObj, 1);
+
+	obj->excel_type = (unsigned)-1; /* Set to undefined */
+	obj->excel_type_name = NULL;
+	obj->id = -1;
+	obj->gnum_obj = NULL;
+	obj->attrs = (attrs != NULL) ? attrs : ms_obj_attr_bag_new ();
+	obj->ignore_combo_in_filter	= FALSE;
+	obj->is_linked			= FALSE;
+
+	return obj;
+}
+
 void
 ms_obj_delete (MSObj *obj)
 {
@@ -237,7 +289,7 @@ ms_obj_delete (MSObj *obj)
 			obj->gnum_obj = NULL;
 		}
 		if (obj->attrs) {
-			ms_object_attr_bag_destroy (obj->attrs);
+			ms_obj_attr_bag_destroy (obj->attrs);
 			obj->attrs = NULL;
 		}
 		g_free (obj);
@@ -263,19 +315,23 @@ ms_read_TXO (BiffQuery *q)
 		"At bottom", "Verticaly justified"
 	};
 
-	guint16 const options     = MS_OLE_GET_GUINT16 (q->data);
-	guint16 const orient      = MS_OLE_GET_GUINT16 (q->data + 2);
-	guint16 const text_len    = MS_OLE_GET_GUINT16 (q->data + 10);
-/*	guint16 const num_formats = MS_OLE_GET_GUINT16 (q->data + 12);*/
+	guint16 const options     = GSF_LE_GET_GUINT16 (q->data);
+	guint16 const orient      = GSF_LE_GET_GUINT16 (q->data + 2);
+	guint16 const text_len    = GSF_LE_GET_GUINT16 (q->data + 10);
+/*	guint16 const num_formats = GSF_LE_GET_GUINT16 (q->data + 12);*/
 	int const halign = (options >> 1) & 0x7;
 	int const valign = (options >> 4) & 0x7;
-	char         *text = g_new (char, text_len + 1);
+	char         *text;
 	guint16       peek_op;
 
+	if (text_len == 0)
+		return NULL;
+
 	g_return_val_if_fail (orient <= 3, NULL);
 	g_return_val_if_fail (1 <= halign && halign <= 4, NULL);
 	g_return_val_if_fail (1 <= valign && valign <= 4, NULL);
 
+	text = g_new (char, text_len + 1);
 	text [0] = '\0';
 	if (ms_biff_query_peek_next (q, &peek_op) &&
 	    peek_op == BIFF_CONTINUE) {
@@ -283,7 +339,7 @@ ms_read_TXO (BiffQuery *q)
 		int i, increment = 1;
 
 		ms_biff_query_next (q);
-		increment = (MS_OLE_GET_GUINT8 (q->data)) ? 2 : 1;
+		increment = (GSF_LE_GET_GUINT8 (q->data)) ? 2 : 1;
 		data = q->data + 1;
 
 		/*
@@ -302,7 +358,7 @@ ms_read_TXO (BiffQuery *q)
 		    peek_op == BIFF_CONTINUE)
 			ms_biff_query_next (q);
 		else
-			g_warning ("Unusual, TXO text with no formatting");
+			g_warning ("Unusual, TXO text with no formatting has 0x%x @ 0x%x", peek_op, q->streamPos);
 	} else if (text_len > 0)
 		g_warning ("TXO len of %d but no continue", text_len);
 
@@ -333,7 +389,7 @@ ms_obj_dump_impl (guint8 const *data, int len, int data_left, char const *name)
 		len = data_left - 4;
 	}
 	if (ms_excel_object_debug > 2)
-		ms_ole_dump (data, len+4);
+		gsf_mem_dump (data, len+4);
 	printf ("}; /* %s */\n", name);
 }
 #else
@@ -344,21 +400,56 @@ ms_obj_dump_impl (guint8 const *data, int len, int data_left, char const *name)
 static gboolean
 ms_obj_read_pre_biff8_obj (BiffQuery *q, MSContainer *container, MSObj *obj)
 {
+	guint16 peek_op;
 	/* TODO : Lots of docs for these things.  Write the parser. */
 
 #if 0
-	guint32 const numObjects = MS_OLE_GET_GUINT16(q->data);
-	guint16 const flags = MS_OLE_GET_GUINT16(q->data+8);
+	guint32 const numObjects = GSF_LE_GET_GUINT16(q->data);
+	guint16 const flags = GSF_LE_GET_GUINT16(q->data+8);
 #endif
 	guint8 *anchor = g_malloc (MS_ANCHOR_SIZE);
 	memcpy (anchor, q->data+8, MS_ANCHOR_SIZE);
-	if (obj->attrs == NULL)
-		obj->attrs = ms_object_attr_bag_new ();
-	ms_object_attr_bag_insert (obj->attrs,
-		ms_object_attr_new_ptr (MS_OBJ_ATTR_ANCHOR, anchor));
+	ms_obj_attr_bag_insert (obj->attrs,
+		ms_obj_attr_new_ptr (MS_OBJ_ATTR_ANCHOR, anchor));
 
-	obj->excel_type = MS_OLE_GET_GUINT16(q->data + 4);
-	obj->id         = MS_OLE_GET_GUINT32(q->data + 6);
+	obj->excel_type = GSF_LE_GET_GUINT16(q->data + 4);
+	obj->id         = GSF_LE_GET_GUINT32(q->data + 6);
+
+	switch (obj->excel_type) {
+	case 9:  /* polygon */
+
+		ms_obj_attr_bag_insert (obj->attrs,
+			ms_obj_attr_new_uint (MS_OBJ_ATTR_FILL_COLOR,
+				0x80000000 | GSF_LE_GET_GUINT8 (q->data+35)));
+		ms_obj_attr_bag_insert (obj->attrs,
+			ms_obj_attr_new_uint (MS_OBJ_ATTR_OUTLINE_COLOR,
+				0x80000000 | GSF_LE_GET_GUINT8 (q->data+38)));
+
+	if (ms_biff_query_peek_next (q, &peek_op) &&
+	    peek_op == BIFF_COORDLIST) {
+		unsigned i, n;
+		guint tmp;
+		GArray *array;
+
+		ms_biff_query_next (q);
+		n = q->length / 2;
+		array = g_array_set_size (
+			g_array_new (FALSE, FALSE, sizeof (double)), n + 2);
+
+		for (i = 0; i < n ; i++) {
+			tmp = GSF_LE_GET_GUINT16 (q->data + 2*i);
+			g_array_index (array, double, i) = (double)tmp/ 16384.;
+		}
+		g_array_index (array, double, i)   = g_array_index (array, double, 0);
+		g_array_index (array, double, i+1) = g_array_index (array, double, 1);
+		ms_obj_attr_bag_insert (obj->attrs,
+			ms_obj_attr_new_array (MS_OBJ_ATTR_POLYGON_COORDS, array));
+	}
+	break;
+
+	default :
+		;
+	}
 
 	return FALSE;
 }
@@ -384,14 +475,14 @@ ms_obj_read_biff8_obj (BiffQuery *q, MSContainer *container, MSObj *obj)
 
 	/* Scan through the pseudo BIFF substream */
 	while (data_len_left > 0 && !hit_end) {
-		guint16 const record_type = MS_OLE_GET_GUINT16(data);
+		guint16 const record_type = GSF_LE_GET_GUINT16(data);
 
 		/* All the sub-records seem to have this layout
 		 * 2001/Mar/29 JEG : liars.  Ok not all records have this
 		 * layout.  Create a list box.  It seems to do something
 		 * unique.  It acts like an end, and has no length specified.
 		 */
-		guint16 len = MS_OLE_GET_GUINT16(data+2);
+		guint16 len = GSF_LE_GET_GUINT16(data+2);
 
 		/* 1st record must be COMMON_OBJ*/
 		g_return_val_if_fail (obj->excel_type >= 0 ||
@@ -422,23 +513,24 @@ ms_obj_read_biff8_obj (BiffQuery *q, MSContainer *container, MSObj *obj)
 			break;
 
 		case GR_PICTURE_OPTIONS :
-		{
-			guint16 pict_opt;
-			g_return_val_if_fail (len == 2, TRUE);
-
-			pict_opt = MS_OLE_GET_GUINT16(data+4);
+			if (len == 2) {
+				guint16 opt = GSF_LE_GET_GUINT16 (data + 4);
 
+				obj->is_linked = (opt & 0x2) ? TRUE : FALSE;
 #ifndef NO_DEBUG_EXCEL
-			if (ms_excel_object_debug >= 1) {
-				printf ("{ /* PictOpt */\n");
-				printf ("value = %d;\n", pict_opt);
-				printf ("}; /* PictOpt */\n");
-			}
+				if (ms_excel_object_debug >= 1) {
+					printf ("{ /* PictOpt */\n");
+					printf ("value = %x;\n", opt);
+					printf ("}; /* PictOpt */\n");
+				}
 #endif
+			} else {
+				/* no docs on this so be careful */
+				g_warning ("PictOpt record with size other than 2");
+			}
 
 			next_biff_record_maybe_imdata = TRUE;
 			break;
-		}
 
 		case GR_PICTURE_FORMULA :
 			ms_obj_dump (data, len, data_len_left, "PictFormula");
@@ -453,21 +545,21 @@ ms_obj_read_biff8_obj (BiffQuery *q, MSContainer *container, MSObj *obj)
 			break;
 
 		case GR_SCROLLBAR : {
-			ms_object_attr_bag_insert (obj->attrs,
-				ms_object_attr_new_uint (MS_OBJ_ATTR_SCROLLBAR_VALUE,
-					MS_OLE_GET_GUINT16 (data+8)));
-			ms_object_attr_bag_insert (obj->attrs,
-				ms_object_attr_new_uint (MS_OBJ_ATTR_SCROLLBAR_MIN,
-					MS_OLE_GET_GUINT16 (data+10)));
-			ms_object_attr_bag_insert (obj->attrs,
-				ms_object_attr_new_uint (MS_OBJ_ATTR_SCROLLBAR_MAX,
-					MS_OLE_GET_GUINT16 (data+12)));
-			ms_object_attr_bag_insert (obj->attrs,
-				ms_object_attr_new_uint (MS_OBJ_ATTR_SCROLLBAR_INC,
-					MS_OLE_GET_GUINT16 (data+14)));
-			ms_object_attr_bag_insert (obj->attrs,
-				ms_object_attr_new_uint (MS_OBJ_ATTR_SCROLLBAR_PAGE,
-					MS_OLE_GET_GUINT16 (data+16)));
+			ms_obj_attr_bag_insert (obj->attrs,
+				ms_obj_attr_new_uint (MS_OBJ_ATTR_SCROLLBAR_VALUE,
+					GSF_LE_GET_GUINT16 (data+8)));
+			ms_obj_attr_bag_insert (obj->attrs,
+				ms_obj_attr_new_uint (MS_OBJ_ATTR_SCROLLBAR_MIN,
+					GSF_LE_GET_GUINT16 (data+10)));
+			ms_obj_attr_bag_insert (obj->attrs,
+				ms_obj_attr_new_uint (MS_OBJ_ATTR_SCROLLBAR_MAX,
+					GSF_LE_GET_GUINT16 (data+12)));
+			ms_obj_attr_bag_insert (obj->attrs,
+				ms_obj_attr_new_uint (MS_OBJ_ATTR_SCROLLBAR_INC,
+					GSF_LE_GET_GUINT16 (data+14)));
+			ms_obj_attr_bag_insert (obj->attrs,
+				ms_obj_attr_new_uint (MS_OBJ_ATTR_SCROLLBAR_PAGE,
+					GSF_LE_GET_GUINT16 (data+16)));
 			ms_obj_dump (data, len, data_len_left, "ScrollBar");
 			break;
 		}
@@ -477,11 +569,11 @@ ms_obj_read_biff8_obj (BiffQuery *q, MSContainer *container, MSObj *obj)
 			break;
 
 		case GR_SCROLLBAR_FORMULA : {
-			guint16 const expr_len = MS_OLE_GET_GUINT16 (data+4);
+			guint16 const expr_len = GSF_LE_GET_GUINT16 (data+4);
 			GnmExpr const *ref = ms_container_parse_expr (container, data+10, expr_len);
 			if (ref != NULL)
-				ms_object_attr_bag_insert (obj->attrs,
-					ms_object_attr_new_expr (MS_OBJ_ATTR_SCROLLBAR_LINK, ref));
+				ms_obj_attr_bag_insert (obj->attrs,
+					ms_obj_attr_new_expr (MS_OBJ_ATTR_SCROLLBAR_LINK, ref));
 			ms_obj_dump (data, len, data_len_left, "ScrollbarFmla");
 			break;
 		}
@@ -515,23 +607,23 @@ ms_obj_read_biff8_obj (BiffQuery *q, MSContainer *container, MSObj *obj)
 		}
 
 		case GR_CHECKBOX_FORMULA : {
-			guint16 const expr_len = MS_OLE_GET_GUINT16 (data+4);
+			guint16 const expr_len = GSF_LE_GET_GUINT16 (data+4);
 			GnmExpr const *ref = ms_container_parse_expr (container, data+10, expr_len);
 			if (ref != NULL)
-				ms_object_attr_bag_insert (obj->attrs,
-					ms_object_attr_new_expr (MS_OBJ_ATTR_CHECKBOX_LINK, ref));
+				ms_obj_attr_bag_insert (obj->attrs,
+					ms_obj_attr_new_expr (MS_OBJ_ATTR_CHECKBOX_LINK, ref));
 			ms_obj_dump (data, len, data_len_left, "CheckBoxFmla");
 			break;
 		}
 
 		case GR_COMMON_OBJ_DATA : {
-			guint16 const options =MS_OLE_GET_GUINT16 (data+8);
+			guint16 const options =GSF_LE_GET_GUINT16 (data+8);
 
 			/* Multiple objects in 1 record ?? */
 			g_return_val_if_fail (obj->excel_type == -1, -1);
 
-			obj->excel_type = MS_OLE_GET_GUINT16(data+4);
-			obj->id = MS_OLE_GET_GUINT16(data+6);
+			obj->excel_type = GSF_LE_GET_GUINT16(data+4);
+			obj->id = GSF_LE_GET_GUINT16(data+6);
 
 			/* Undocumented.  It appears that combos for filters are marked
 			 * with flag 0x100
@@ -605,7 +697,7 @@ ms_obj_read_biff8_obj (BiffQuery *q, MSContainer *container, MSObj *obj)
 	/* The ftEnd record should have been the last */
 	if (data_len_left > 0) {
 		printf("OBJ : unexpected extra data after Object End record;\n");
-		ms_ole_dump (data, data_len_left);
+		gsf_mem_dump (data, data_len_left);
 		return TRUE;
 	}
 
@@ -636,7 +728,7 @@ ms_obj_read_biff8_obj (BiffQuery *q, MSContainer *container, MSObj *obj)
  * @attrs : an OPTIONAL hash of object attributes.
  */
 void
-ms_read_OBJ (BiffQuery *q, MSContainer *container, GHashTable *attrs)
+ms_read_OBJ (BiffQuery *q, MSContainer *container, MSObjAttrBag *attrs)
 {
 	static char const * const object_type_names[] =
 	{
@@ -668,14 +760,7 @@ ms_read_OBJ (BiffQuery *q, MSContainer *container, GHashTable *attrs)
 	};
 
 	gboolean errors;
-	MSObj *obj = g_new0 (MSObj, 1);
-
-	obj->excel_type = (unsigned)-1; /* Set to undefined */
-	obj->excel_type_name = NULL;
-	obj->id = -1;
-	obj->gnum_obj = NULL;
-	obj->attrs = attrs;
-	obj->ignore_combo_in_filter = FALSE;
+	MSObj *obj = ms_obj_new (attrs);
 
 #ifndef NO_DEBUG_EXCEL
 	if (ms_excel_object_debug > 0)
