@@ -23,6 +23,7 @@
  */
 
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include <gnumeric.h>
 #include <func.h>
 
@@ -32,7 +33,6 @@
 #include <expr.h>
 #include <value.h>
 #include <auto-format.h>
-#include <libgnome/gnome-i18n.h>
 #include <mathfunc.h>
 
 #include "plugin.h"
