@@ -6,6 +6,7 @@
  *  Miguel de Icaza (miguel@gnu.org)
  *  Sean Atkinson (sca20@cam.ac.uk)
  *  Jukka-Pekka Iivonen (iivonen@iki.fi)
+ *  Almer S. Tigelaar (almer@gnome.org)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +23,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include <gnumeric.h>
 #include <func.h>
 
@@ -41,7 +43,6 @@
 #include <math.h>
 #include <limits.h>
 #include <string.h>
-#include <libgnome/gnome-i18n.h>
 
 #include "plugin.h"
 #include "plugin-util.h"
@@ -56,7 +57,7 @@ static const char *help_char = {
 	   "@SYNTAX=CHAR(x)\n"
 
 	   "@DESCRIPTION="
-	   "CHAR returns the ASCII character represented by the number @x."
+	   "CHAR returns the ASCII character represented by the number @x.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "CHAR(65) equals A.\n"
@@ -82,8 +83,8 @@ static const char *help_code = {
 	   "@SYNTAX=CODE(char)\n"
 
 	   "@DESCRIPTION="
-	   "CODE returns the ASCII number for the character @char.\n"
-           "This function is Excel compatible. "
+	   "CODE returns the ASCII number for the character @char.\n\n"
+           "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "CODE(\"A\") equals 65.\n"
@@ -105,8 +106,8 @@ static const char *help_exact = {
 
 	   "@DESCRIPTION="
 	   "EXACT returns true if @string1 is exactly equal to @string2 "
-	   "(this routine is case sensitive).\n"
-           "This function is Excel compatible."
+	   "(this routine is case sensitive).\n\n"
+           "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "EXACT(\"key\",\"key\") equals TRUE.\n"
@@ -118,8 +119,8 @@ static const char *help_exact = {
 static Value *
 gnumeric_exact (FunctionEvalInfo *ei, Value **argv)
 {
-	return value_new_bool (strcmp (value_peek_string (argv[0]),
-				       value_peek_string (argv[1])) == 0);
+	return value_new_bool (g_utf8_collate (value_peek_string (argv[0]),
+					       value_peek_string (argv[1])) == 0);
 }
 
 /***************************************************************************/
@@ -129,8 +130,8 @@ static const char *help_len = {
 	   "@SYNTAX=LEN(string)\n"
 
 	   "@DESCRIPTION="
-	   "LEN returns the length in characters of the string @string.\n"
-           "This function is Excel compatible."
+	   "LEN returns the length in characters of the string @string.\n\n"
+           "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "len(\"Helsinki\") equals 8.\n"
@@ -152,8 +153,8 @@ static const char *help_left = {
 
 	   "@DESCRIPTION="
 	   "LEFT returns the leftmost @num_chars characters or the left "
-	   "character if @num_chars is not specified.\n"
-           "This function is Excel compatible. "
+	   "character if @num_chars is not specified.\n\n"
+           "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "LEFT(\"Directory\",3) equals \"Dir\".\n"
@@ -164,19 +165,20 @@ static const char *help_left = {
 static Value *
 gnumeric_left (FunctionEvalInfo *ei, Value **argv)
 {
-	Value *v;
-	char *s;
 	char const *peek;
-	int count;
+	int         count, newlen;
 
 	count = argv[1] ? value_get_as_int (argv[1]) : 1;
-	peek = value_peek_string (argv[0]);
-	s = g_new (gchar, strlen (peek) + 1);
-	g_utf8_strncpy (s, peek, count);
-	v = value_new_string (s);
-	g_free (s);
 
-	return v;
+	if (count < 0)
+		return value_new_error (ei->pos, gnumeric_err_VALUE);
+
+	peek = value_peek_string (argv[0]);
+	if (count >= g_utf8_strlen (peek, -1))
+		return value_new_string (peek);
+
+	newlen = g_utf8_offset_to_pointer (peek, count) - peek;
+	return value_new_string_nocopy (g_strndup (peek, newlen));
 }
 
 /***************************************************************************/
@@ -186,8 +188,8 @@ static const char *help_lower = {
 	   "@SYNTAX=LOWER(text)\n"
 
 	   "@DESCRIPTION="
-	   "LOWER returns a lower-case version of the string in @text.\n"
-           "This function is Excel compatible."
+	   "LOWER returns a lower-case version of the string in @text.\n\n"
+           "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "LOWER(\"J. F. Kennedy\") equals \"j. f. kennedy\".\n"
@@ -198,15 +200,7 @@ static const char *help_lower = {
 static Value *
 gnumeric_lower (FunctionEvalInfo *ei, Value **argv)
 {
-	Value *v;
-	char *s;
-
-	s = value_get_as_string (argv[0]);
-	g_strdown (s);
-	v = value_new_string (s);
-	g_free (s);
-
-	return v;
+	return value_new_string_nocopy (g_utf8_strdown (value_peek_string (argv[0]), -1));
 }
 
 /***************************************************************************/
@@ -217,8 +211,8 @@ static const char *help_mid = {
 
 	   "@DESCRIPTION="
 	   "MID returns a substring from @string starting at @position for "
-	   "@length characters.\n"
-           "This function is Excel compatible."
+	   "@length characters.\n\n"
+           "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "MID(\"testing\",2,3) equals \"est\".\n"
@@ -229,29 +223,29 @@ static const char *help_mid = {
 static Value *
 gnumeric_mid (FunctionEvalInfo *ei, Value **argv)
 {
-	Value *v;
-	int pos, len;
-	char *s;
+	char       *upos;
 	char const *source;
+	int         pos, len, ulen, slen;
 
 	pos = value_get_as_int (argv[1]);
 	len = value_get_as_int (argv[2]);
 
 	if (len < 0 || pos <= 0)
-		return value_new_error (ei->pos, _("Invalid arguments"));
+		return value_new_error (ei->pos, gnumeric_err_VALUE);
+
+	source = value_peek_string (argv[0]);
+	slen   = g_utf8_strlen (source, -1);
+
+	if (pos > slen)
+		return value_new_error (ei->pos, gnumeric_err_VALUE);
 
 	pos--;  /* Make pos zero-based.  */
 
-	source = value_peek_string (argv[0]);
-	len = MIN (len, (int)strlen (source) - pos);
+	len  = MIN (len, slen - pos);
+	upos = g_utf8_offset_to_pointer (source, pos);
+	ulen = g_utf8_offset_to_pointer (upos, len) - upos;
 
-	s = g_new (gchar, len + 1);
-	memcpy (s, source + pos, len);
-	s[len] = '\0';
-	v = value_new_string (s);
-	g_free (s);
-
-	return v;
+	return value_new_string_nocopy (g_strndup (upos, ulen));
 }
 
 /***************************************************************************/
@@ -262,8 +256,8 @@ static const char *help_right = {
 
 	   "@DESCRIPTION="
 	   "RIGHT returns the rightmost @num_chars characters or the right "
-	   "character if @num_chars is not specified.\n"
-           "This function is Excel compatible. "
+	   "character if @num_chars is not specified.\n\n"
+           "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "RIGHT(\"end\") equals \"d\".\n"
@@ -275,22 +269,27 @@ static const char *help_right = {
 static Value *
 gnumeric_right (FunctionEvalInfo *ei, Value **argv)
 {
-	Value *v;
 	int count, slen;
+	char const *os;
 	char *s;
 
 	count = argv[1] ? value_get_as_int (argv[1]) : 1;
-	s = value_get_as_string (argv[0]);
 
-	slen = strlen (s);
-	if (count < slen) {
-		memmove (s, s + (slen - count), count);
-		s[count] = 0;
+	if (count < 0)
+		return value_new_error (ei->pos, gnumeric_err_VALUE);
+
+	os   = value_peek_string (argv[0]);
+	slen = g_utf8_strlen (os, -1);
+
+	if (count < slen)
+		s = g_strdup (g_utf8_offset_to_pointer (os, slen - count));
+	else {
+		/* We could just duplicate the arg, but that would not ensure
+		   that the result was a string.  */
+		s = g_strdup (os);
 	}
-	v = value_new_string (s);
-	g_free (s);
 
-	return v;
+	return value_new_string_nocopy (s);
 }
 
 /***************************************************************************/
@@ -300,8 +299,8 @@ static const char *help_upper = {
 	   "@SYNTAX=UPPER(text)\n"
 
 	   "@DESCRIPTION="
-	   "UPPER returns a upper-case version of the string in @text.\n"
-           "This function is Excel compatible."
+	   "UPPER returns a upper-case version of the string in @text.\n\n"
+           "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "UPPER(\"canceled\") equals \"CANCELED\".\n"
@@ -312,15 +311,7 @@ static const char *help_upper = {
 static Value *
 gnumeric_upper (FunctionEvalInfo *ei, Value **argv)
 {
-	Value *v;
-	char *s;
-
-	s = value_get_as_string (argv[0]);
-	g_strup (s);
-	v = value_new_string (s);
-	g_free (s);
-
-	return v;
+	return value_new_string_nocopy (g_utf8_strup (value_peek_string (argv[0]), -1));
 }
 
 /***************************************************************************/
@@ -329,8 +320,8 @@ static const char *help_concatenate = {
 	N_("@FUNCTION=CONCATENATE\n"
 	   "@SYNTAX=CONCATENATE(string1[,string2...])\n"
 	   "@DESCRIPTION="
-	   "CONCATENATE returns up appended strings.\n"
-           "This function is Excel compatible."
+	   "CONCATENATE returns up appended strings.\n\n"
+           "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "CONCATENATE(\"aa\",\"bb\") equals \"aabb\".\n"
@@ -345,7 +336,6 @@ gnumeric_concatenate (FunctionEvalInfo *ei, GnmExprList *nodes)
 				      range_concatenate,
 				      COLLECT_IGNORE_BLANKS,
 				      gnumeric_err_VALUE);
-
 }
 
 /***************************************************************************/
@@ -354,8 +344,8 @@ static const char *help_rept = {
 	N_("@FUNCTION=REPT\n"
 	   "@SYNTAX=REPT(string,num)\n"
 	   "@DESCRIPTION="
-	   "REPT returns @num repetitions of @string.\n"
-           "This function is Excel compatible. "
+	   "REPT returns @num repetitions of @string.\n\n"
+           "* This function is Excel compatible.\n "
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "REPT(\".\",3) equals \"...\".\n"
@@ -366,17 +356,18 @@ static const char *help_rept = {
 static Value *
 gnumeric_rept (FunctionEvalInfo *ei, Value **argv)
 {
-	Value *v;
-	char *s, *p;
+	GString    *res;
 	const char *source;
-	int num;
-	int len;
+	int         num;
+	int         len;
+	int         i;
 
 	num = value_get_as_int (argv[1]);
 	if (num < 0)
 		return value_new_error (ei->pos, gnumeric_err_VALUE);
+
 	source = value_peek_string (argv[0]);
-	len = strlen (source);
+	len    = strlen (source);
 
 	/* Fast special case.  =REPT ("",2^30) should not take long.  */
 	if (len == 0 || num == 0)
@@ -386,21 +377,11 @@ gnumeric_rept (FunctionEvalInfo *ei, Value **argv)
 	if (num >= INT_MAX / len)
 		return value_new_error (ei->pos, gnumeric_err_VALUE);
 
-	p = s = g_new (gchar, 1 + len * num);
-	if (!p)
-		/* FIXME: this and above case should probably have the
-		   same error message.  */
-		return value_new_error (ei->pos, _("Out of memory"));
+	res = g_string_sized_new (len * num);
+	for (i = 0; i < num; i++)
+		g_string_append (res, source);
 
-	while (num--) {
-		memcpy (p, source, len);
-		p += len;
-	}
-	*p = '\0';
-	v = value_new_string (s);
-	g_free (s);
-
-	return v;
+	return value_new_string_nocopy (g_string_free (res, FALSE));
 }
 
 /***************************************************************************/
@@ -409,8 +390,8 @@ static const char *help_clean = {
 	N_("@FUNCTION=CLEAN\n"
 	   "@SYNTAX=CLEAN(string)\n"
 	   "@DESCRIPTION="
-	   "CLEAN removes any non-printable characters from @string.\n"
-           "This function is Excel compatible."
+	   "CLEAN removes any non-printable characters from @string.\n\n"
+           "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "CLEAN(\"one\"\\&char(7)) equals \"one\".\n"
@@ -421,18 +402,19 @@ static const char *help_clean = {
 static Value *
 gnumeric_clean (FunctionEvalInfo *ei, Value **argv)
 {
-	Value *res;
-	unsigned char *s, *p, *q;
+	const char *s = value_peek_string (argv[0]);
+	GString *res = g_string_sized_new (strlen (s));
 
-	s = (unsigned char *)value_get_as_string (argv[0]);
-	for (p = q = s; *p; p++)
-		if (isprint (*p))
-			*q++ = *p;
-	*q = 0;
-	res = value_new_string ((char *)s);
-	g_free (s);
+	while (*s) {
+		gunichar uc = g_utf8_get_char (s);
 
-	return res;
+		if (g_unichar_isprint (uc))
+			g_string_append_unichar (res, uc);
+
+		s = g_utf8_next_char (s);
+	}
+
+	return value_new_string_nocopy (g_string_free (res, FALSE));
 }
 
 /***************************************************************************/
@@ -443,8 +425,8 @@ static const char *help_find = {
 	   "@DESCRIPTION="
 	   "FIND returns position of @string1 in @string2 (case-sensitive), "
 	   "searching only from character @start onwards (assuming 1 if "
-	   "omitted).\n"
-           "This function is Excel compatible."
+	   "omitted).\n\n"
+           "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "FIND(\"ac\",\"Jack\") equals 2.\n"
@@ -458,19 +440,35 @@ gnumeric_find (FunctionEvalInfo *ei, Value **argv)
 	int count, haystacksize;
 	const char *haystack, *needle;
 
-	needle = value_peek_string (argv[0]);
+	/*
+	 * FIXME: My gut feeling is that we should return arguments
+	 * invalid when g_utf8_strlen (needle, -1) is 0 (i.e. needle is "")
+	 * Currently we return "1" which seems nonsensical.
+	 */
+	needle   = value_peek_string (argv[0]);
 	haystack = value_peek_string (argv[1]);
-	count = argv[2] ? value_get_as_int (argv[2]) : 1;
+	count    = argv[2] ? value_get_as_int (argv[2]) : 1;
 
-	haystacksize = strlen (haystack);
+	haystacksize = g_utf8_strlen (haystack, -1);
 
+	/*
+	 * NOTE: It seems that the implementation of g_strstr will
+	 * even work for utf8 string, even though there is no special
+	 * utf8 version for it, this is why we use "strlen (haystart)"
+	 * and not g_utf8_strlen below
+	 */
 	if (count <= 0 || count > haystacksize) {
 		return value_new_error (ei->pos, gnumeric_err_VALUE);
 	} else {
-		const char *haystart = haystack + (count - 1);
-		const char *p = strstr (haystart, needle);
+		const char *haystart = g_utf8_offset_to_pointer (haystack,
+								 count - 1);
+		const char *p        = g_strstr_len (haystart,
+						     strlen (haystart), needle);
+
 		if (p)
-			return value_new_int (count + (p - haystart));
+			/* One-based */
+			return value_new_int
+				(g_utf8_pointer_to_offset (haystack, p) + 1);
 		else
 			/* Really?  */
 			return value_new_error (ei->pos, gnumeric_err_VALUE);
@@ -485,8 +483,8 @@ static const char *help_fixed = {
 	   "@DESCRIPTION="
 	   "FIXED returns @num as a formatted string with @decimals numbers "
 	   "after the decimal point, omitting commas if requested by "
-	   "@no_commas.\n"
-           "This function is Excel compatible."
+	   "@no_commas.\n\n"
+           "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "FIXED(1234.567,2) equals \"1,234.57\".\n"
@@ -510,7 +508,7 @@ gnumeric_fixed (FunctionEvalInfo *ei, Value **argv)
 		gboolean err;
 		commas = !value_get_as_bool (argv[2], &err);
 		if (err)
-			return value_new_error (ei->pos, _("Type Mismatch"));
+			return value_new_error (ei->pos, gnumeric_err_VALUE);
 	}
 
 	if (decimals >= 127) /* else buffer overflow */
@@ -552,8 +550,8 @@ static const char *help_proper = {
 	   "@SYNTAX=PROPER(string)\n"
 
 	   "@DESCRIPTION="
-	   "PROPER returns @string with initial of each word capitalised.\n"
-           "This function is Excel compatible."
+	   "PROPER returns @string with initial of each word capitalised.\n\n"
+           "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "PROPER(\"j. f. kennedy\") equals \"J. F. Kennedy\".\n"
@@ -569,26 +567,32 @@ static const char *help_proper = {
 static Value *
 gnumeric_proper (FunctionEvalInfo *ei, Value **argv)
 {
-	Value *v;
-	unsigned char *s, *p;
-	gboolean inword = FALSE;
+	char const *p;
+	GString    *res    = g_string_new ("");
+	gboolean   inword = FALSE;
 
-	s = (unsigned char *)value_get_as_string (argv[0]);
-	for (p = s; *p; p++) {
-		if (isalpha (*p)) {
+	p = value_peek_string (argv[0]);
+	while (*p) {
+		gunichar uc = g_utf8_get_char (p);
+
+		if (g_unichar_isalpha (uc)) {
 			if (inword) {
-				*p = tolower (*p);
+				g_string_append_unichar
+					(res, g_unichar_tolower (uc));
 			} else {
-				*p = toupper (*p);
+				g_string_append_unichar
+					(res, g_unichar_toupper (uc));
 				inword = TRUE;
 			}
-		} else
+		} else {
+			g_string_append_unichar (res, uc);
 			inword = FALSE;
+		}
+
+		p = g_utf8_next_char (p);
 	}
 
-	v = value_new_string ((char *)s);
-	g_free (s);
-	return v;
+	return value_new_string_nocopy (g_string_free (res, FALSE));
 }
 
 /***************************************************************************/
@@ -598,8 +602,8 @@ static const char *help_replace = {
 	   "@SYNTAX=REPLACE(old,start,num,new)\n"
 	   "@DESCRIPTION="
 	   "REPLACE returns @old with @new replacing @num characters from "
-	   "@start.\n"
-           "This function is Excel compatible."
+	   "@start.\n\n"
+           "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "REPLACE(\"testing\",2,3,\"*****\") equals \"t*****ing\".\n"
@@ -610,35 +614,33 @@ static const char *help_replace = {
 static Value *
 gnumeric_replace (FunctionEvalInfo *ei, Value **argv)
 {
-	Value *v;
-	GString *s;
-	gint start, num, oldlen, newlen;
+	GString *res;
+	gint start, num, oldlen;
 	char const *old;
 	char const *new;
 
-	start = value_get_as_int (argv[1]);
-	num = value_get_as_int (argv[2]);
-	old = value_peek_string (argv[0]);
-	oldlen = strlen (old);
+	start  = value_get_as_int (argv[1]);
+	num    = value_get_as_int (argv[2]);
+	old    = value_peek_string (argv[0]);
+	oldlen = g_utf8_strlen (old, -1);
 
 	if (start <= 0 || num <= 0)
 		return value_new_error (ei->pos, gnumeric_err_VALUE);
+	if (start > oldlen)
+		return value_new_error (ei->pos, _ ("Arguments out of range"));
+
 	start--;  /* Make this zero-based.  */
 
 	if (start + num > oldlen)
 		num = oldlen - start;
 
 	new = value_peek_string (argv[3]);
-	newlen = strlen (new);
 
-	s = g_string_new (old);
-	g_string_erase (s, start, num);
-	g_string_insert (s, start, new);
+	res = g_string_new (old);
+	g_string_erase (res, start, num);
+	g_string_insert (res, start, new);
 
-	v = value_new_string (s->str);
-	g_string_free (s, TRUE);
-
-	return v;
+	return value_new_string_nocopy (g_string_free (res, FALSE));
 }
 
 /***************************************************************************/
@@ -649,8 +651,8 @@ static const char *help_t_ = {
 	   "@SYNTAX=T(value)\n"
 	   "@DESCRIPTION="
 	   "T returns @value if and only if it is text, otherwise a blank "
-	   "string.\n"
-           "This function is Excel compatible."
+	   "string.\n\n"
+           "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "T(\"text\") equals \"text\".\n"
@@ -676,8 +678,8 @@ static const char *help_text = {
 	N_("@FUNCTION=TEXT\n"
 	   "@SYNTAX=TEXT(value,format_text)\n"
 	   "@DESCRIPTION="
-	   "TEXT returns @value as a string with the specified format.\n"
-           "This function is Excel compatible."
+	   "TEXT returns @value as a string with the specified format.\n\n"
+           "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "TEXT(3.223,\"$0.00\") equals \"$3.22\".\n"
@@ -689,10 +691,11 @@ static const char *help_text = {
 static Value *
 gnumeric_text (FunctionEvalInfo *ei, Value **args)
 {
-	StyleFormat *format = style_format_new_XL (value_peek_string (args[1]), TRUE);
-	Value *res, *tmp = NULL;
+	StyleFormat *format = style_format_new_XL (value_peek_string (args[1]),
+						   TRUE);
+	Value       *res, *tmp = NULL;
 	Value const *arg  = args[0];
-	gboolean ok = FALSE;
+	gboolean    ok = FALSE;
 
 	if (arg->type == VALUE_STRING) {
 		Value *match = format_match (value_peek_string (arg), NULL);
@@ -724,8 +727,8 @@ static const char *help_trim = {
 	N_("@FUNCTION=TRIM\n"
 	   "@SYNTAX=TRIM(text)\n"
 	   "@DESCRIPTION="
-	   "TRIM returns @text with only single spaces between words.\n"
-           "This function is Excel compatible."
+	   "TRIM returns @text with only single spaces between words.\n\n"
+           "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "TRIM(\"  a bbb  cc\") equals \"a bbb cc\".\n"
@@ -736,32 +739,38 @@ static const char *help_trim = {
 static Value *
 gnumeric_trim (FunctionEvalInfo *ei, Value **argv)
 {
-	Value *v;
-	gchar *new, *dest, *src;
-	gboolean space = TRUE;
+	const char *s;
+	GString  *res   = g_string_new ("");
+	gboolean  space = TRUE;
+	int       len;
 
-	src = dest = new = value_get_as_string (argv[0]);
+	s = value_peek_string (argv[0]);
+	while (*s) {
+		gunichar uc = g_utf8_get_char (s);
 
-	while (*src) {
-		if (*src == ' ') {
+		/*
+		 * FIXME: This takes care of tabs and the likes too
+		 * is that the desired behaviour?
+		 */
+		if (g_unichar_isspace (uc)) {
 			if (!space) {
-				*dest++ = *src;
+				g_string_append_unichar (res, uc);
 				space = TRUE;
 			}
 		} else {
+			g_string_append_unichar (res, uc);
 			space = FALSE;
-			*dest++ = *src;
 		}
-		src++;
+
+		s = g_utf8_next_char (s);
 	}
-	if (space && dest > new)
-		dest--;
-	*dest = '\0';
 
-	v = value_new_string (new);
-	g_free (new);
+	g_warning ("FIXME: this looks bogus.");
+	len = g_utf8_strlen (res->str, -1);
+	if (space && len > 0)
+		g_string_truncate (res, len - 1);
 
-	return v;
+	return value_new_string_nocopy (g_string_free (res, FALSE));
 }
 
 /***************************************************************************/
@@ -770,8 +779,8 @@ static const char *help_value = {
 	N_("@FUNCTION=VALUE\n"
 	   "@SYNTAX=VALUE(text)\n"
 	   "@DESCRIPTION="
-	   "VALUE returns numeric value of @text.\n"
-           "This function is Excel compatible."
+	   "VALUE returns numeric value of @text.\n\n"
+           "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "VALUE(\"$1,000\") equals 1000.\n"
@@ -791,14 +800,13 @@ gnumeric_value (FunctionEvalInfo *ei, Value **argv)
 
 	default: {
 		Value *v;
-		unsigned char *p, *arg = (unsigned char *)value_get_as_string (argv[0]);
+		const char *p, *arg = value_peek_string (argv[0]);
 
 		/* Skip leading spaces */
-		for (p = arg ; *p && isspace (*p) ; ++p)
+		for (p = arg; *p && g_unichar_isspace (g_utf8_get_char (p));
+		     p = g_utf8_next_char (p))
 			;
-
-		v = format_match_number ((char *)p, NULL);
-		g_free (arg);
+		v = format_match_number (p, NULL);
 
 		if (v != NULL)
 			return v;
@@ -815,8 +823,8 @@ static const char *help_substitute = {
 	   "@DESCRIPTION="
 	   "SUBSTITUTE replaces @old with @new in @text.  Substitutions "
 	   "are only applied to instance @num of @old in @text, otherwise "
-	   "every one is changed.\n"
-           "This function is Excel compatible."
+	   "every one is changed.\n\n"
+           "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "SUBSTITUTE(\"testing\",\"test\",\"wait\") equals \"waiting\".\n"
@@ -835,9 +843,9 @@ subs_string_new (guint len)
 {
 	struct subs_string *s = g_new (struct subs_string, 1);
 
-	s->len = 0;
-	s->mem = len;
-	s->str = g_new (gchar, len);
+	s->len  = 0;
+	s->mem  = len;
+	s->str  = g_new (gchar, len);
 	*s->str = '\0';
 	return s;
 }
@@ -929,8 +937,8 @@ static const char *help_dollar = {
 	N_("@FUNCTION=DOLLAR\n"
 	   "@SYNTAX=DOLLAR(num[,decimals])\n"
 	   "@DESCRIPTION="
-	   "DOLLAR returns @num formatted as currency.\n"
-           "This function is Excel compatible."
+	   "DOLLAR returns @num formatted as currency.\n\n"
+           "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "DOLLAR(12345) equals \"$12,345.00\".\n"
@@ -941,55 +949,64 @@ static const char *help_dollar = {
 static Value *
 gnumeric_dollar (FunctionEvalInfo *ei, Value **argv)
 {
-	Value *v, *ag[3];
-	guint len, neg;
-	gchar *s;
-	static int barfed = 0;
+	gboolean precedes, space_sep;
+	char const *curr = format_get_currency (&precedes, &space_sep);
+	char *format, *s;
+	StyleFormat *sf;
+	const char *base_format =
+		"%s#,##0%s%s;(%s#,##0%s)%s;_(%s\"-\"??%s_);_(@_)";
+        gnum_float number = value_get_as_float (argv[0]);
+        int decimals = argv[1] ? value_get_as_int (argv[1]) : 2;
+	gnum_float p10;
+	Value *v;
+	char dotdecimals[1000];
 
-	gnum_float x;
-	int     i, n;
-
-	if (!barfed) {
-		g_warning ("GNUMERIC_DOLLAR is broken, it should use the "
-			   "format_value routine");
-		barfed = 1;
+	if (decimals > 0) {
+		/* ".0000" */
+		decimals = MIN (decimals, (int)sizeof (dotdecimals) - 2); /* FIXME? */
+		dotdecimals[0] = '.';
+		memset (&dotdecimals[1], '0', decimals);
+		dotdecimals[decimals + 1] = 0;
+	} else {
+		dotdecimals[0] = 0;
 	}
-	if (argv[1] != NULL) {
-		x = 0.5;
-		n = value_get_as_int (argv[1]);
-		for (i = 0; i < n; i++)
-			x /= 10;
-		ag[0] = value_new_float (value_get_as_float (argv[0]) + x);
-	} else
-		ag[0] = value_duplicate (argv[0]);
 
-	ag[1] = argv[1];
-	ag[2] = NULL;
+	if (precedes) {
+		char *pre = g_strconcat ("\"", curr, "\"",
+					 (space_sep ? " " : ""),
+					 NULL);
 
-	v = gnumeric_fixed (ei, ag);
-	if (v == NULL)
-		return NULL;
+		format = g_strdup_printf (base_format,
+					  pre, dotdecimals, "",
+					  pre, dotdecimals, "",
+					  pre, "");
+		g_free (pre);
+	} else {
+		char *post = g_strconcat ((space_sep ? " " : ""),
+					  "\"", curr, "\"",
+					  NULL);
 
-	g_assert (v->type == VALUE_STRING);
-
-	len = strlen (v->v_str.val->str);
-	neg = (v->v_str.val->str[0] == '-') ? 1 : 0;
-
-	s = g_new (gchar, len + 2 + neg);
-	strncpy (&s[1], v->v_str.val->str, len);
-
-	string_unref (v->v_str.val);
-	if (neg) {
-		s[0] = '(';
-		s[len + 1] = ')';
+		format = g_strdup_printf (base_format,
+					  "", dotdecimals, post,
+					  "", dotdecimals, post,
+					  "", post);
+		g_free (post);
 	}
-	/* FIXME: should use *lc->currency_symbol */
-	s[neg] = '$';
-	s[len + 1 + neg] = '\0';
-	v->v_str.val = string_get_nocopy (s);
-	value_release (ag[0]);
+	sf = style_format_new_XL (format, FALSE);
+	g_free (format);
+	g_return_val_if_fail (sf != NULL,
+			      value_new_error (ei->pos, gnumeric_err_NA));
 
-	return v;
+	/* Since decimals can be negative, round the number.  */
+	p10 = gpow10 (decimals);
+	number = gnumeric_fake_round (number * p10) / p10;
+	v = value_new_float (number);
+	s = format_value (sf, v, NULL, -1);
+	value_release (v);
+
+	style_format_unref (sf);
+
+	return value_new_string_nocopy (s);
 }
 
 /***************************************************************************/
@@ -1003,18 +1020,18 @@ static const char *help_search = {
 	   "@within is the string in which you want to search.  @start_num "
 	   "is the start position of the search in @within.  If @start_num "
 	   "is omitted, it is assumed to be one.  The search is not case "
-	   "sensitive. "
+	   "sensitive.\n"
 	   "\n"
 	   "@text can contain wildcard characters (*) and question marks (?) "
 	   "to control the search.  A question mark matches with any "
 	   "character and wildcard matches with any string including empty "
 	   "string.  If you want the actual wildcard or question mark to "
-	   "be searched, use tilde (~) before the character. "
+	   "be searched, use tilde (~) before the character.\n"
 	   "\n"
-	   "If @text is not found, SEARCH returns #VALUE! error. "
-	   "If @start_num is less than one or it is greater than the length "
+	   "* If @text is not found, SEARCH returns #VALUE! error.\n"
+	   "* If @start_num is less than one or it is greater than the length "
 	   "of @within, SEARCH returns #VALUE! error.\n"
-           "This function is Excel compatible."
+           "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "SEARCH(\"c\",\"Cancel\") equals 1.\n"
@@ -1220,28 +1237,51 @@ match_again:
 /***************************************************************************/
 
 const ModulePluginFunctionInfo string_functions[] = {
-        { "char",       "f",     "number",                  &help_char,        gnumeric_char, NULL, NULL, NULL },
-        { "clean",      "S",     "text",                    &help_clean,       gnumeric_clean, NULL, NULL, NULL },
-        { "code",       "S",     "text",                    &help_code,        gnumeric_code, NULL, NULL, NULL },
-        { "concatenate", 0,      "text1,text2",             &help_concatenate, NULL, gnumeric_concatenate, NULL, NULL },
-        { "dollar",     "f|f",   "num,decimals",            &help_dollar,      gnumeric_dollar, NULL, NULL, NULL },
-        { "exact",      "SS",    "text1,text2",             &help_exact,       gnumeric_exact, NULL, NULL, NULL },
-        { "find",       "SS|f",  "text1,text2,num",         &help_find,        gnumeric_find, NULL, NULL, NULL },
-        { "fixed",      "f|fb",  "num,decs,no_commas",      &help_fixed,       gnumeric_fixed, NULL, NULL, NULL },
-        { "left",       "S|f",   "text,num_chars",          &help_left,        gnumeric_left, NULL, NULL, NULL },
-        { "len",        "S",     "text",                    &help_len,         gnumeric_len, NULL, NULL, NULL },
-        { "lower",      "S",     "text",                    &help_lower,       gnumeric_lower, NULL, NULL, NULL },
-        { "proper",     "S",     "text",                    &help_proper,      gnumeric_proper, NULL, NULL, NULL },
-        { "mid",        "Sff",   "text,pos,num",            &help_mid,         gnumeric_mid, NULL, NULL, NULL },
-        { "replace",    "SffS",  "old,start,num,new",       &help_replace,     gnumeric_replace, NULL, NULL, NULL },
-        { "rept",       "Sf",    "text,num",                &help_rept,        gnumeric_rept, NULL, NULL, NULL },
-        { "right",      "S|f",   "text,num_chars",          &help_right,       gnumeric_right, NULL, NULL, NULL },
-        { "search",     "SS|f",  "find,within[,start_num]", &help_search,      gnumeric_search, NULL, NULL, NULL },
-        { "substitute", "SSS|f", "text,old,new,num",        &help_substitute,  gnumeric_substitute, NULL, NULL, NULL },
-        { "t",          "?",     "value",                   &help_t_,          gnumeric_t_, NULL, NULL, NULL },
-        { "text",       "Ss",    "value,format_text",       &help_text,        gnumeric_text, NULL, NULL, NULL },
-        { "trim",       "S",     "text",                    &help_trim,        gnumeric_trim, NULL, NULL, NULL },
-        { "upper",      "S",     "text",                    &help_upper,       gnumeric_upper, NULL, NULL, NULL },
-        { "value",      "?",     "text",                    &help_value,       gnumeric_value, NULL, NULL, NULL },
+        { "char",       "f",     N_("number"),                  &help_char,
+	  gnumeric_char, NULL, NULL, NULL },
+        { "clean",      "S",     N_("text"),                    &help_clean,
+       gnumeric_clean, NULL, NULL, NULL },
+        { "code",       "S",     N_("text"),                    &help_code,
+	  gnumeric_code, NULL, NULL, NULL },
+        { "concatenate", 0,      N_("text,text,"),            &help_concatenate,
+	  NULL, gnumeric_concatenate, NULL, NULL },
+        { "dollar",     "f|f",   N_("num,decimals"),            &help_dollar,
+	  gnumeric_dollar, NULL, NULL, NULL },
+        { "exact",      "SS",    N_("text1,text2"),             &help_exact,
+	  gnumeric_exact, NULL, NULL, NULL },
+        { "find",       "SS|f",  N_("text1,text2,num"),         &help_find,
+	  gnumeric_find, NULL, NULL, NULL },
+        { "fixed",      "f|fb",  N_("num,decs,no_commas"),      &help_fixed,
+	  gnumeric_fixed, NULL, NULL, NULL },
+        { "left",       "S|f",   N_("text,num_chars"),          &help_left,
+	  gnumeric_left, NULL, NULL, NULL },
+        { "len",        "S",     N_("text"),                    &help_len,
+	  gnumeric_len, NULL, NULL, NULL },
+        { "lower",      "S",     N_("text"),                    &help_lower,
+	  gnumeric_lower, NULL, NULL, NULL },
+        { "proper",     "S",     N_("text"),                    &help_proper,
+	  gnumeric_proper, NULL, NULL, NULL },
+        { "mid",        "Sff",   N_("text,pos,num"),            &help_mid,
+	  gnumeric_mid, NULL, NULL, NULL },
+        { "replace",    "SffS",  N_("old,start,num,new"),       &help_replace,
+	  gnumeric_replace, NULL, NULL, NULL },
+        { "rept",       "Sf",    N_("text,num"),                &help_rept,
+	  gnumeric_rept, NULL, NULL, NULL },
+        { "right",      "S|f",   N_("text,num_chars"),          &help_right,
+	  gnumeric_right, NULL, NULL, NULL },
+        { "search",     "SS|f",  N_("find,within,start_num"),   &help_search,
+	  gnumeric_search, NULL, NULL, NULL },
+        { "substitute", "SSS|f", N_("text,old,new,num"),       &help_substitute,
+	  gnumeric_substitute, NULL, NULL, NULL },
+        { "t",          "?",     N_("value"),                   &help_t_,
+          gnumeric_t_, NULL, NULL, NULL },
+        { "text",       "Ss",    N_("value,format_text"),       &help_text,
+	  gnumeric_text, NULL, NULL, NULL },
+        { "trim",       "S",     N_("text"),                    &help_trim,
+	  gnumeric_trim, NULL, NULL, NULL },
+        { "upper",      "S",     N_("text"),                    &help_upper,
+	  gnumeric_upper, NULL, NULL, NULL },
+        { "value",      "?",     N_("text"),                    &help_value,
+	  gnumeric_value, NULL, NULL, NULL },
         {NULL}
 };
