@@ -20,6 +20,7 @@
  * USA
  */
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include <gnumeric.h>
 #include "qpro.h"
 
@@ -41,17 +42,21 @@
 #include <gsf/gsf-input.h>
 #include <gsf/gsf-infile.h>
 #include <gsf/gsf-infile-msole.h>
-#include <libgnome/gnome-i18n.h>
 
 GNUMERIC_MODULE_PLUGIN_INFO_DECL;
 
+gboolean qpro_file_probe (GnumFileOpener const *fo, GsfInput *input,
+			  FileProbeLevel pl);
+void     qpro_file_open (GnumFileOpener const *fo, IOContext *context,
+			 WorkbookView *new_wb_view, GsfInput *input);
+
 static gboolean
 qpro_check_signature (GsfInput *input)
 {
 	guint8 const *header;
 	guint16 version;
 
-	if (gsf_input_seek (input, 0, GSF_SEEK_SET) ||
+	if (gsf_input_seek (input, 0, G_SEEK_SET) ||
 	    NULL == (header = gsf_input_read (input, 2+2+2, NULL)) ||
 	    GSF_LE_GET_GUINT16 (header + 0) != 0 ||
 	    GSF_LE_GET_GUINT16 (header + 2) != 2)
@@ -461,7 +466,7 @@ qpro_read_workbook (QProReadState *state, GsfInput *input)
 	guint8 const *data;
 
 	state->input = input;
-	gsf_input_seek (input, 0, GSF_SEEK_SET);
+	gsf_input_seek (input, 0, G_SEEK_SET);
 
 	while (NULL != (data = qpro_get_record (state, &id, &len))) {
 		switch (id) {
