@@ -6,6 +6,7 @@
  */
 
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include <gnumeric.h>
 #include <string.h>
 #include <errno.h>
@@ -27,7 +28,6 @@
 
 #include <gsf/gsf-input.h>
 #include <gsf/gsf-input-textline.h>
-#include <libgnome/gnome-i18n.h>
 #include <string.h>
 #include <math.h>
 
@@ -423,7 +423,7 @@ sc_file_probe (GnumFileOpener const *fo, GsfInput *input,
 	       FileProbeLevel pl)
 {
 	char const *header = NULL;
-	if (!gsf_input_seek (input, 0, GSF_SEEK_SET))
+	if (!gsf_input_seek (input, 0, G_SEEK_SET))
 		header = gsf_input_read (input, sizeof (signature)-1, NULL);
 	return header != NULL &&
 	    memcmp (header, signature, sizeof (signature)-1) == 0;
