@@ -11,6 +11,7 @@
  */
 
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include <gnumeric.h>
 #include "file.h"
 #include "io-context.h"
@@ -24,7 +25,6 @@
 #include "plugin.h"
 #include "module-plugin-defs.h"
 
-#include <libgnome/gnome-i18n.h>
 #include <string.h>
 #include <gsf/gsf-input-stdio.h>
 #include <gsf/gsf-input-textline.h>
@@ -418,7 +418,7 @@ gboolean
 sylk_file_probe (GnumFileOpener const *fo, GsfInput *input, FileProbeLevel pl)
 {
 	char const *header = NULL;
-	if (!gsf_input_seek (input, 0, GSF_SEEK_SET))
+	if (!gsf_input_seek (input, 0, G_SEEK_SET))
 		header = gsf_input_read (input, 3, NULL);
 	return (header != NULL && strncmp (header, "ID;", 3) == 0);
 }
