@@ -9,7 +9,7 @@ typedef enum {
 	 * one of them can be set. Indicates
 	 * what sort of consolidation we will
 	 * execute
-	 */ 
+	 */
 	CONSOLIDATE_ROW_LABELS   = 1 << 0,
 	CONSOLIDATE_COL_LABELS   = 1 << 1,
 
@@ -41,10 +41,11 @@ void         consolidate_free (Consolidate *cs);
 void         consolidate_set_function    (Consolidate *cs, FunctionDefinition *fd);
 void         consolidate_set_mode        (Consolidate *cs, ConsolidateMode mode);
 
-gboolean     consolidate_set_destination (Consolidate *cs, Sheet *sheet, Range const *r);
-gboolean     consolidate_add_source      (Consolidate *cs, Sheet *sheet, Range const *r);
+gboolean     consolidate_set_destination (Consolidate *cs, Value *range);
+gboolean     consolidate_add_source      (Consolidate *cs, Value *range);
 
 Range        consolidate_get_dest_bounding_box (Consolidate *cs);
-void         consolidate_apply                 (Consolidate *cs);
+void         consolidate_apply                 (Consolidate *cs,
+						WorkbookControl *wbc);
 
 #endif
