@@ -19,14 +19,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include <gnumeric.h>
 #include "dialogs.h"
 
 #include <workbook.h>
 #include <gui-util.h>
 
-#include <libgnome/gnome-i18n.h>
-
 #define ABOUT_KEY          "about-dialog"
 
 /*
