@@ -31,6 +31,7 @@
  */
 
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include <gnumeric.h>
 #include "dialogs.h"
 
@@ -38,7 +39,6 @@
 #include <gui-util.h>
 #include <workbook-edit.h>
 
-#include <libgnome/gnome-i18n.h>
 #include <glade/glade.h>
 #include <gsf/gsf-impl-utils.h>
 #include <gal/util/e-util.h>
