@@ -22,6 +22,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  **/
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include <gnumeric.h>
 #include "dialogs.h"
 
@@ -29,7 +30,6 @@
 #include <workbook-control-gui-priv.h>
 #include <gui-util.h>
 
-#include <libgnome/gnome-i18n.h>
 #include <glade/glade.h>
 
 typedef struct {
