@@ -23,6 +23,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include <gnumeric.h>
 #include "dialogs.h"
 
@@ -37,7 +38,6 @@
 #include <parse-util.h>
 #include <widgets/gnumeric-expr-entry.h>
 
-#include <libgnome/gnome-i18n.h>
 #include <glade/glade.h>
 
 #define LIST_KEY "name_list_data"
