@@ -20,6 +20,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include <gnumeric.h>
 #include "dialogs.h"
 
@@ -32,7 +33,6 @@
 #include <cmd-edit.h>
 #include <workbook-edit.h>
 
-#include <libgnome/gnome-i18n.h>
 #include <glade/glade.h>
 
 #define GLADE_FILE "delete-cells.glade"
