@@ -21,6 +21,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include <gnumeric.h>
 #include "dialogs.h"
 
@@ -35,7 +36,6 @@
 #include <style.h>
 #include <gnumeric-gconf.h>
 
-#include <libgnome/gnome-i18n.h>
 #include <libgnomeprint/gnome-print-master.h>
 #include <libgnomeprint/gnome-print-unit.h>
 #include <libgnomeprintui/gnome-print-paper-selector.h>
