@@ -21,6 +21,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include <gnumeric.h>
 #include "dialogs.h"
 
@@ -33,7 +34,6 @@
 #include <application.h>
 #include <workbook-cmd-format.h>
 
-#include <libgnome/gnome-i18n.h>
 #include <glade/glade.h>
 
 #define GLADE_FILE "row-height.glade"
