@@ -23,6 +23,7 @@
  */
 
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include <gnumeric.h>
 #include "dialogs.h"
 
@@ -41,7 +42,6 @@
 
 #include <glade/glade.h>
 #include <gal/util/e-util.h>
-#include <libgnome/gnome-i18n.h>
 #include <string.h>
 
 #define SOLVER_KEY            "solver-dialog"
@@ -59,9 +59,11 @@ typedef struct {
 	GtkWidget           *add_button;
 	GtkWidget           *change_button;
 	GtkWidget           *delete_button;
+	GtkWidget           *model_button;
 	GnumericExprEntry   *lhs_entry;
 	GnumericExprEntry   *rhs_entry;
 	GtkOptionMenu       *type_combo;
+	GtkOptionMenu       *algorithm_combo;
 	GtkCList            *constraint_list;
 	gint                selected_row;
 	gnum_float          ov_target;
@@ -90,6 +92,21 @@ static char const * constraint_strs_untranslated[] = {
 };
 #endif
 
+
+
+typedef struct {
+	char const          *name;
+	SolverAlgorithmType alg;
+	SolverModelType     type;
+} algorithm_def_t;
+
+static algorithm_def_t algorithm_defs [] = {
+	{ N_("Revised Simplex (GLPK 3.2)"), GLPKSimplex, SolverLPModel },
+	{ N_("Simplex (LP Solve 3.2)"), LPSolve, SolverLPModel },
+	{ N_("< Not available >"), QPDummy, SolverQPModel },
+	{ NULL, 0, 0 }
+};
+
 typedef struct {
 	GtkCList *c_listing;
 	GSList   *c_list;
@@ -117,6 +134,9 @@ static const char *model_type_group[] = {
 	0
 };
 
+static GList *lp_alg_name_list = NULL;
+static GList *qp_alg_name_list = NULL;
+
 /**
  * is_hom_row_or_col_ref:
  * @Widget:
@@ -186,7 +206,6 @@ dialog_set_sec_button_sensitivity (GtkWidget *dummy, SolverState *state)
 	gtk_widget_set_sensitive (state->delete_button, select_ready);
 }
 
-
 /**
  * constraint_select_click:
  * @clist:
@@ -378,6 +397,44 @@ cb_dialog_set_rhs_sensitivity (GtkWidget *dummy, SolverState *state)
 	}
 }
 
+/**
+ * cb_dialog_lp_clicked:
+ * @button:
+ * @state:
+ *
+ *
+ **/
+static void
+cb_dialog_model_type_clicked (GtkWidget *button, SolverState *state)
+{
+	SolverModelType type;
+
+	type = gnumeric_glade_group_value (state->gui, model_type_group);
+	switch (type) {
+	case SolverLPModel:
+		gtk_combo_set_popdown_strings
+			(GTK_COMBO (state->algorithm_combo), lp_alg_name_list);
+		gtk_widget_set_sensitive (GTK_WIDGET (state->solve_button),
+					  TRUE);
+		break;
+	case SolverQPModel:
+		gtk_combo_set_popdown_strings
+			(GTK_COMBO (state->algorithm_combo), qp_alg_name_list);
+		gtk_widget_set_sensitive (GTK_WIDGET (state->solve_button),
+					  FALSE);
+		gnumeric_notice_nonmodal ((GtkWindow *) state->dialog,
+					  &(state->warning_dialog),
+					  GTK_MESSAGE_INFO, 
+					  _("Looking for a subject for your "
+					    "thesis? Maybe you would like to "
+					    "write a QP solver for "
+					    "Gnumeric?"));
+		break;
+	default:
+		break;
+	}
+}
+
 /**
  * free_original_values:
  * @ov:
@@ -847,6 +904,20 @@ cb_dialog_solve_clicked (GtkWidget *button, SolverState *state)
 		gnumeric_glade_group_value (state->gui, problem_type_group);
 	param->options.model_type =
 		gnumeric_glade_group_value (state->gui, model_type_group);
+
+	for (i = 0; algorithm_defs [i].name; i++) {
+		GtkEntry             *entry = GTK_ENTRY 
+			(GTK_COMBO (state->algorithm_combo)->entry);
+		G_CONST_RETURN gchar *name = gtk_entry_get_text (entry);
+
+		if (param->options.model_type == algorithm_defs [i].type)
+			if (strcmp (algorithm_defs [i].name, name) == 0) {
+				param->options.algorithm =
+					algorithm_defs [i].alg;
+				break;
+			}
+	}
+
 	param->options.assume_non_negative = gtk_toggle_button_get_active
 		(GTK_TOGGLE_BUTTON (glade_xml_get_widget (state->gui,
 							  "non_neg_button")));
@@ -860,27 +931,10 @@ cb_dialog_solve_clicked (GtkWidget *button, SolverState *state)
 		(GTK_TOGGLE_BUTTON (glade_xml_get_widget
 				    (state->gui, "show_iter_button")));
 
-	if (entry_to_int (GTK_ENTRY(state->max_iter_entry), 
-			  &param->options.max_iter, TRUE)) {
-		gnumeric_notice_nonmodal (GTK_WINDOW(state->dialog),
-					  &(state->warning_dialog),
-					  GTK_MESSAGE_ERROR,
-					  _("The value given in 'Max "
-					    "Iterations' is not valid."));
-		focus_on_entry (GTK_ENTRY(state->max_iter_entry));
-		return;
-	}
-
-	if (entry_to_int (GTK_ENTRY(state->max_time_entry), 
-			  &param->options.max_time_sec, TRUE)) {
-		gnumeric_notice_nonmodal (GTK_WINDOW(state->dialog),
-					  &(state->warning_dialog),
-					  GTK_MESSAGE_ERROR,
-					  _("The value given in 'Max Time "
-					    "(sec.)' is not valid."));
-		focus_on_entry (GTK_ENTRY(state->max_time_entry));
-		return;
-	}
+	param->options.max_iter = gtk_spin_button_get_value
+		(GTK_SPIN_BUTTON (state->max_iter_entry));
+	param->options.max_time_sec = gtk_spin_button_get_value
+		(GTK_SPIN_BUTTON (state->max_time_entry));
 
 	answer = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (
 	        glade_xml_get_widget (state->gui, "answer")));
@@ -970,9 +1024,28 @@ dialog_init (SolverState *state)
 	GtkTable                *table;
 	constraint_conversion_t conv;
 	SolverParameters        *param;
+	int                     i;
 
 	param = state->sheet->solver_parameters;
 
+	if (lp_alg_name_list == NULL) {
+		for (i = 0; algorithm_defs [i].name; i++)
+			switch (algorithm_defs [i].type) {
+			case SolverLPModel:
+				lp_alg_name_list = g_list_append
+					(lp_alg_name_list,
+					 (gpointer) algorithm_defs [i].name);
+				break;
+			case SolverQPModel:
+				qp_alg_name_list = g_list_append
+					(qp_alg_name_list,
+					 (gpointer) algorithm_defs [i].name);
+				break;
+			default:
+				break;
+			}
+	}
+
 	state->gui = gnumeric_glade_xml_new (state->wbcg, "solver.glade");
         if (state->gui == NULL)
                 return TRUE;
@@ -1051,6 +1124,26 @@ dialog_init (SolverState *state)
 	g_signal_connect_after (G_OBJECT (state->change_cell_entry), "changed",
 		G_CALLBACK (dialog_set_main_button_sensitivity), state);
 
+	/* Algorithm */
+	state->algorithm_combo = GTK_OPTION_MENU
+		(glade_xml_get_widget (state->gui, "algorithm_combo"));
+	switch (param->options.model_type) {
+	case SolverLPModel:
+		gtk_combo_set_popdown_strings
+			(GTK_COMBO (state->algorithm_combo), lp_alg_name_list);
+		break;
+	case SolverQPModel:
+		gtk_combo_set_popdown_strings
+			(GTK_COMBO (state->algorithm_combo), qp_alg_name_list);
+		break;
+	default:
+		break;
+	}
+	state->model_button =
+		glade_xml_get_widget(state->gui, "lp_model_button");
+	g_signal_connect (G_OBJECT (state->model_button), "clicked",
+			  G_CALLBACK (cb_dialog_model_type_clicked), state);
+
 	/* Options */
 	state->max_iter_entry = glade_xml_get_widget (state->gui,
 						      "max_iter_entry");
@@ -1166,12 +1259,10 @@ dialog_init (SolverState *state)
 			param->problem_type == SolverMinimize);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (
 		glade_xml_get_widget(state->gui, "lp_model_button")),
-			param->options.model_type
-				      == SolverLPModel);
+			param->options.model_type == SolverLPModel);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (
 		glade_xml_get_widget(state->gui, "qp_model_button")),
-			param->options.model_type
-				      == SolverQPModel);
+			param->options.model_type == SolverQPModel);
 
 	conv.c_listing = state->constraint_list;
 	conv.c_list    = param->constraints;
