@@ -19,12 +19,13 @@ struct _GnmNamedExpr {
 	} t;
 };
 
-GnmNamedExpr *expr_name_new	  (char const *name, gboolean builtin);
 GnmNamedExpr *expr_name_lookup (ParsePos const *pos, char const *name);
+
+GnmNamedExpr *expr_name_new    (char const *name, gboolean builtin);
 GnmNamedExpr *expr_name_add    (ParsePos const *pp, char const *name,
-				   GnmExpr const *expr, char const **error_msg);
+				GnmExpr const *expr, char const **error_msg);
 GnmNamedExpr *expr_name_create (ParsePos const *pp, char const *name,
-				   char const *expr_str, ParseError *error);
+				char const *expr_str, ParseError *error);
 
 void	 expr_name_ref	      (GnmNamedExpr *exprn);
 void	 expr_name_unref      (GnmNamedExpr *exprn);
@@ -38,7 +39,7 @@ void	 expr_name_set_expr   (GnmNamedExpr *ne, GnmExpr const *new_expr,
 void	 expr_name_add_dep    (GnmNamedExpr *ne, Dependent *dep);
 void	 expr_name_remove_dep (GnmNamedExpr *ne, Dependent *dep);
 
-void expr_name_list_destroy (GList *names);
+void expr_name_list_destroy (GList **names);
 
 void expr_name_init       (void);
 void expr_name_shutdown   (void);
