@@ -3,6 +3,7 @@
  * expr.c : Expression evaluation in Gnumeric
  *
  * Copyright (C) 2001-2002 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 1998-2000 Miguel de Icaza (miguel@gnu.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -19,6 +20,7 @@
  * USA
  */
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include "gnumeric.h"
 #include "expr.h"
 
@@ -42,7 +44,6 @@
 #include <math.h>
 #include <string.h>
 #include <stdlib.h>
-#include <libgnome/gnome-i18n.h>
 
 /*
  * Using pools here probably does not save anything, but it's a darn
