@@ -7,16 +7,10 @@
  *   Zbigniew Chyla (cyba@gnome.pl)
  */
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include "gnumeric.h"
 #include "file.h"
 
-#ifdef WITH_BONOBO
-#include <bonobo.h>
-#include <bonobo/bonobo-stream.h>
-#include <libgnome/gnome-util.h>
-#include <sys/stat.h>
-#include <unistd.h>
-#endif
 #include "file-priv.h"
 #include "io-context.h"
 #include "command-context.h"
@@ -31,7 +25,6 @@
 #include <gsf/gsf-input.h>
 #include <gsf/gsf-impl-utils.h>
 #include <string.h>
-#include <libgnome/gnome-i18n.h>
 
 static void
 gnum_file_opener_init (GnumFileOpener *fo)
@@ -243,7 +236,11 @@ gnum_file_saver_save_real (GnumFileSaver const *fs, IOContext *io_context,
 	fs->save_func (fs, io_context, wbv, file_name);
 }
 
-#ifdef WITH_BONOBO
+#if defined(GNOME2_CONVERSION_COMPLETE) && defined(WITH_BONOBO)
+#include <bonobo.h>
+#include <bonobo/bonobo-stream.h>
+#include <sys/stat.h>
+#include <unistd.h>
 #define FILE_COPY_CHUNK_SIZE  0x10000
 
 static void
