@@ -19,10 +19,10 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include <gnumeric.h>
 #include <func.h>
 #include <func-builtin.h>
-#include <libgnome/gnome-i18n.h>
 #include <rangefunc.h>
 #include <auto-format.h>
 #include <collect.h>
