@@ -10,6 +10,7 @@
  *  Jody Goldberg   (jody@gnome.org)
  */
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include "gnumeric.h"
 #include "func.h"
 
@@ -29,29 +30,33 @@
 
 #include <string.h>
 #include <glib.h>
-#include <libgnome/gnome-i18n.h>
 #include <stdlib.h>
 #include <ctype.h>
 
-static GList *categories = NULL;
-static SymbolTable *global_symbol_table = NULL;
+static GList *categories;
+static SymbolTable *global_symbol_table;
 
-extern void stat_functions_init        (void);
-extern void database_functions_init    (void);
+static FunctionCategory *unknown_cat;
+static GSList *unknown_functions;
 
 void
 functions_init (void)
 {
 	global_symbol_table = symbol_table_new ();
-
-	stat_functions_init ();
-	database_functions_init ();
 	func_builtin_init ();
 }
 
 void
 functions_shutdown (void)
 {
+	g_assert ((unknown_cat == NULL) == (unknown_functions == NULL));
+
+	while (unknown_functions) {
+		FunctionDefinition *func = unknown_functions->data;
+		function_remove (unknown_cat, function_def_get_name (func));
+		unknown_functions = g_slist_remove (unknown_functions, func);
+	}
+
 	func_builtin_shutdown ();
 }
 
@@ -122,6 +127,11 @@ function_category_compare (gconstpointer a, gconstpointer b)
 	g_return_val_if_fail (cat_a->display_name != NULL, 0);
 	g_return_val_if_fail (cat_b->display_name != NULL, 0);
 
+#if 0
+	str_a = g_utf8_casefold (cat_a->display_name->str, -1);
+	str_b = g_utf8_casefold (cat_b->display_name->str, -1);
+#endif
+
 	str_a = g_alloca (strlen (cat_a->display_name->str) + 1);
 	str_b = g_alloca (strlen (cat_b->display_name->str) + 1);
 	g_strdown (strcpy (str_a, cat_a->display_name->str));
@@ -133,7 +143,7 @@ function_category_compare (gconstpointer a, gconstpointer b)
 FunctionCategory *
 function_get_category (gchar const *name)
 {
-	return function_get_category_with_translation (name, NULL);
+	return function_get_category_with_translation (name, _(name));
 }
 
 FunctionCategory *
@@ -296,6 +306,9 @@ func_ref (FunctionDefinition *fn_def)
 	g_return_if_fail (fn_def != NULL);
 
 	fn_def->ref_count++;
+	if (fn_def->ref_count == 1 && fn_def->ref_notify != NULL) {
+		fn_def->ref_notify (fn_def, 1);
+	}
 }
 
 void
@@ -305,6 +318,9 @@ func_unref (FunctionDefinition *fn_def)
 	g_return_if_fail (fn_def->ref_count > 0);
 
 	fn_def->ref_count--;
+	if (fn_def->ref_count == 0 && fn_def->ref_notify != NULL) {
+		fn_def->ref_notify (fn_def, 0);
+	}
 }
 
 gint
@@ -357,7 +373,8 @@ static FunctionDefinition *
 fn_def_new (FunctionCategory *category,
 	    char const *name,
 	    char const *arg_names,
-	    char const **help)
+	    char const **help,
+	    FuncRefNotify opt_ref_notify)
 {
 	FunctionDefinition *fn_def;
 
@@ -371,6 +388,7 @@ fn_def_new (FunctionCategory *category,
 	fn_def->unlink	= NULL;
 	fn_def->user_data = NULL;
 	fn_def->ref_count = 0;
+	fn_def->ref_notify = opt_ref_notify;
 
 	if (category != NULL)
 		function_category_add_func (category, fn_def);
@@ -385,7 +403,8 @@ function_add_args (FunctionCategory *category,
 		   char const *args,
 		   char const *arg_names,
 		   char const **help,
-		   FunctionArgs fn)
+		   FunctionArgs fn,
+		   FuncRefNotify opt_ref_notify)
 {
 	static char const valid_tokens[] = "fsbraAS?|";
 	FunctionDefinition *fn_def;
@@ -399,7 +418,7 @@ function_add_args (FunctionCategory *category,
 		g_return_val_if_fail (strchr (valid_tokens, *ptr), NULL);
 	}
 
-	fn_def = fn_def_new (category, name, arg_names, help);
+	fn_def = fn_def_new (category, name, arg_names, help, opt_ref_notify);
 	if (fn_def != NULL) {
 		fn_def->fn_type = FUNCTION_ARGS;
 		fn_def->fn.args.func = fn;
@@ -415,7 +434,8 @@ function_add_nodes (FunctionCategory *category,
 		    char const *args,
 		    char const *arg_names,
 		    char const **help,
-		    FunctionNodes fn)
+		    FunctionNodes fn,
+		    FuncRefNotify opt_ref_notify)
 {
 	FunctionDefinition *fn_def;
 
@@ -424,7 +444,7 @@ function_add_nodes (FunctionCategory *category,
 		g_warning ("Arg spec for node function -- why?");
 	}
 
-	fn_def = fn_def_new (category, name, arg_names, help);
+	fn_def = fn_def_new (category, name, arg_names, help, opt_ref_notify);
 	if (fn_def != NULL) {
 		fn_def->fn_type     = FUNCTION_NODES;
 		fn_def->fn.fn_nodes = fn;
@@ -435,11 +455,12 @@ function_add_nodes (FunctionCategory *category,
 FunctionDefinition *
 function_add_name_only (FunctionCategory *category,
                         gchar const *name,
-                        FunctionGetFullInfoCallback callback)
+                        FunctionGetFullInfoCallback callback,
+                        FuncRefNotify opt_ref_notify)
 {
 	FunctionDefinition *fn_def;
 
-	fn_def = fn_def_new (category, name, NULL, NULL);
+	fn_def = fn_def_new (category, name, NULL, NULL, opt_ref_notify);
 	if (fn_def != NULL) {
 		fn_def->fn_type = FUNCTION_NAMEONLY;
 		fn_def->get_full_info_callback = callback;
@@ -466,12 +487,13 @@ unknownFunctionHandler (FunctionEvalInfo *ei, GnmExprList *expr_node_list)
 FunctionDefinition *
 function_add_placeholder (char const *name, char const *type)
 {
-	FunctionCategory *cat;
 	FunctionDefinition *func = func_lookup_by_name (name, NULL);
+	const char *unknown_cat_name = N_("Unknown Function");
 
 	g_return_val_if_fail (func == NULL, func);
 
-	cat = function_get_category_with_translation ("Unknown Function", _("Unknown Function"));
+	if (!unknown_cat)
+		unknown_cat = function_get_category (unknown_cat_name);
 
 	/*
 	 * TODO TODO TODO : should add a
@@ -479,9 +501,10 @@ function_add_placeholder (char const *name, char const *type)
 	 * This will allow a user to load a missing
 	 * plugin to supply missing functions.
 	 */
-	func = function_add_nodes (cat, g_strdup (name),
+	func = function_add_nodes (unknown_cat, g_strdup (name),
 				   0, "...", NULL,
-				   &unknownFunctionHandler);
+				   &unknownFunctionHandler, NULL);
+	unknown_functions = g_slist_prepend (unknown_functions, func);
 
 	/* WISHLIST : it would be nice to have a log if these. */
 	g_warning ("Unknown %sfunction : %s", type, name);
@@ -657,6 +680,8 @@ function_def_get_arg_name (FunctionDefinition const *fn_def,
 {
 	gchar **names, **o_names;
 	gchar *name;
+	gchar *translated_arguments;
+	gchar delimiter[2];
 
 	g_return_val_if_fail (arg_idx >= 0, NULL);
 	g_return_val_if_fail (fn_def != NULL, NULL);
@@ -667,7 +692,13 @@ function_def_get_arg_name (FunctionDefinition const *fn_def,
 	if (!fn_def->named_arguments)
 		return NULL;
 
-	names = g_strsplit (fn_def->named_arguments, ",", G_MAXINT);
+	translated_arguments = _(fn_def->named_arguments);
+	delimiter[0] = 
+		strcmp (translated_arguments, fn_def->named_arguments) == 0
+		? ','
+		: format_get_arg_sep ();
+	delimiter[1] = 0;
+	names = g_strsplit (translated_arguments, delimiter, G_MAXINT);
 	o_names = names;
 
 	while (arg_idx-- && *names) {
@@ -715,7 +746,7 @@ function_marshal_arg (FunctionEvalInfo *ei,
 	case 'f':
 	case 'b':
 		if (v->type == VALUE_CELLRANGE) {
-			v = gnm_expr_implicit_intersection (ei->pos, v);
+			v = value_intersection (v, ei->pos);
 			if (v == NULL)
 				break;
 		} else if (v->type == VALUE_ARRAY) {
@@ -747,7 +778,7 @@ function_marshal_arg (FunctionEvalInfo *ei,
 
 	case 's':
 		if (v->type == VALUE_CELLRANGE) {
-			v = gnm_expr_implicit_intersection (ei->pos, v);
+			v = value_intersection (v, ei->pos);
 			if (v == NULL)
 				break;
 		} else if (v->type == VALUE_ARRAY) {
@@ -805,7 +836,7 @@ function_marshal_arg (FunctionEvalInfo *ei,
 
 	case 'S':
 		if (v->type == VALUE_CELLRANGE) {
-			v = gnm_expr_implicit_intersection (ei->pos, v);
+			v = value_intersection (v, ei->pos);
 			if (v == NULL)
 				break;
 		} else if (v->type == VALUE_ARRAY) {
@@ -837,13 +868,15 @@ free_values (Value **values, int top)
  * function_call_with_list:
  * @ei: EvalInfo containing valid fn_def!
  * @args: GnmExprList of GnmExpr args.
+ * @flags :
  *
  * Do the guts of calling a function.
  *
- * Return value:
+ * Returns the result.
  **/
 Value *
-function_call_with_list (FunctionEvalInfo *ei, GnmExprList *l)
+function_call_with_list (FunctionEvalInfo *ei, GnmExprList *l,
+			 GnmExprEvalFlags flags)
 {
 	FunctionDefinition const *fn_def;
 	int argc, arg;
@@ -980,7 +1013,7 @@ typedef struct {
  */
 static Value *
 cb_iterate_cellrange (Sheet *sheet, int col, int row,
-		      Cell *cell, void *user_data)
+		      Cell *cell, gpointer user_data)
 {
 	IterateCallbackClosure *data = user_data;
 	Value *res;
@@ -1013,10 +1046,10 @@ cb_iterate_cellrange (Sheet *sheet, int col, int row,
 Value *
 function_iterate_do_value (EvalPos const *ep,
 			   FunctionIterateCB  callback,
-			   void		*closure,
+			   gpointer	 closure,
 			   Value	*value,
 			   gboolean      strict,
-			   gboolean	 ignore_blank)
+			   CellIterFlags iter_flags)
 {
 	Value *res = NULL;
 
@@ -1036,8 +1069,7 @@ function_iterate_do_value (EvalPos const *ep,
 		res = (*callback)(ep, value, closure);
 		break;
 
-	case VALUE_ARRAY:
-	{
+	case VALUE_ARRAY: {
 		int x, y;
 
 		/* Note the order here.  */
@@ -1046,7 +1078,7 @@ function_iterate_do_value (EvalPos const *ep,
 				res = function_iterate_do_value (
 					ep, callback, closure,
 					value->v_array.vals [x][y],
-					strict, TRUE);
+					strict, CELL_ITER_IGNORE_BLANK);
 				if (res != NULL)
 					return res;
 			}
@@ -1060,7 +1092,7 @@ function_iterate_do_value (EvalPos const *ep,
 		data.closure  = closure;
 		data.strict   = strict;
 
-		res = workbook_foreach_cell_in_range (ep, value, ignore_blank,
+		res = workbook_foreach_cell_in_range (ep, value, iter_flags,
 						      cb_iterate_cellrange,
 						      &data);
 	}
@@ -1080,7 +1112,7 @@ function_iterate_do_value (EvalPos const *ep,
  *                   will stop and that error will be returned.  If FALSE, an
  *                   error will be passed on to the callback (as a Value *
  *                   of type VALUE_ERROR).
- * @ignore_blank:    If TRUE blanks will not be passed to the callback.
+ * @iter_flags:
  *
  * Return value:
  *    NULL            : if no errors were reported.
@@ -1098,7 +1130,7 @@ function_iterate_argument_values (EvalPos const		*ep,
 				  void			*callback_closure,
 				  GnmExprList		*expr_node_list,
 				  gboolean		 strict,
-				  gboolean		 ignore_blank)
+				  CellIterFlags		 iter_flags)
 {
 	Value * result = NULL;
 
@@ -1121,7 +1153,7 @@ function_iterate_argument_values (EvalPos const		*ep,
 		}
 
 		result = function_iterate_do_value (ep, callback, callback_closure,
-						    val, strict, ignore_blank);
+						    val, strict, iter_flags);
 		value_release (val);
 	}
 	return result;
