@@ -1,3 +1,4 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * utils.c:  Various utility routines that do not depend on the GUI of Gnumeric
  *
@@ -7,6 +8,7 @@
  *    Zbigniew Chyla (cyba@gnome.pl)
  */
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include "gnumeric.h"
 #include "gutils.h"
 
@@ -14,7 +16,6 @@
 #include "ranges.h"
 #include "mathfunc.h"
 
-#include <libgnome/gnome-i18n.h>
 #include <stdlib.h>
 #include <math.h>
 #include <stdio.h>
@@ -272,30 +273,6 @@ g_slist_free_custom (GSList *list, GFreeFunc free_func)
 	g_slist_free (list);
 }
 
-/**
- * g_lang_score_in_lang_list:
- *
- */
-gint
-g_lang_score_in_lang_list (gchar *lang, GList *lang_list)
-{
-	if (lang_list == NULL)
-		lang_list = (GList *)gnome_i18n_get_language_list ("LC_MESSAGES");
-
-	if (lang == NULL) {
-		return g_list_length (lang_list);
-	} else {
-		GList *lang_item;
-
-		lang_item = g_list_find_custom (lang_list, lang, g_str_compare);
-		if (lang_item != NULL) {
-			return g_list_position (lang_list, lang_item);
-		} else {
-			return G_MAXINT;
-		}
-	}
-}
-
 gint
 gnumeric_strcase_equal (gconstpointer v1, gconstpointer v2)
 {
@@ -914,3 +891,13 @@ gnm_extension_pointer (char const * path)
 	return path + strlen(path);
 }
 
+/**
+ * gnm_iconv_close : A utility wrapper to safely clos an iconv handle
+ * @handle :
+ **/
+void
+gnm_iconv_close (GIConv handle)
+{
+	if (handle != NULL && handle != ((GIConv)-1))
+		g_iconv_close (handle);
+}
