@@ -58,7 +58,7 @@ void       workbook_io_progress_update (IOContext *io_context, gint inc);
 void       io_progress_unset      (IOContext *io_context);
 
 char *gnm_io_get_password        	 (IOContext *context, char const *msg);
-void  gnm_io_warning        		 (IOContext *context, char const *msg);
+void  gnm_io_warning        		 (IOContext *context, char const *fmt, ...) G_GNUC_PRINTF (2, 3);
 void  gnm_io_warning_unknown_font	 (IOContext *context, char const *font_name);
 void  gnm_io_warning_unknown_function	 (IOContext *context, char const *funct_name);
 void  gnm_io_warning_unsupported_feature (IOContext *context, char const *feature);
