@@ -8,6 +8,7 @@
  *   Miguel de Icaza (miguel@gnu.org)
  */
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include "gnumeric.h"
 #include "libgnumeric.h"
 
@@ -50,16 +51,9 @@ extern gboolean EmbeddableGridFactory_init (void);
 #include <gal/widgets/e-cursors.h>
 #include <glade/glade.h>
 
-#include <libgnome/gnome-config.h>
-
-#ifdef USE_WM_ICONS
-#include <libgnomeui/gnome-window-icon.h>
-#endif
-
 #ifdef WITH_BONOBO
 #include <bonobo.h>
 #endif
-#include <libgnome/gnome-i18n.h>
 
 /* The debugging level */
 int gnumeric_debugging = 0;
@@ -106,6 +100,7 @@ gnumeric_check_for_components (void)
 }
 #endif
 
+extern char *gnumeric_data_dir;
 /*
  * FIXME: We hardcode the GUI command context. Change once we are able
  * to tell whether we are in GUI or not.
@@ -113,10 +108,6 @@ gnumeric_check_for_components (void)
 void
 gnm_common_init (void)
 {
-#ifdef USE_WM_ICONS
-	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-gnumeric.png");
-#endif
-
 	g_object_new (GNUMERIC_APPLICATION_TYPE, NULL);
 	value_init ();
 	expr_init ();
@@ -189,7 +180,6 @@ gnm_shutdown (void)
 
 	global_gnome_font_shutdown ();
 
-	gnome_config_drop_all ();
 	application_release_gconf_client ();
 	
 	g_object_unref (gnumeric_application_get_app ());
