@@ -9,6 +9,7 @@
  */
 
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include "gnumeric.h"
 #include "libgnumeric.h"
 
@@ -17,9 +18,9 @@
 #include "workbook-view.h"
 #include "plugin.h"
 #include "workbook.h"
+#include "gui-file.h"
 #include "gnumeric-gconf.h"
 
-#include <libgnome/gnome-i18n.h>
 #include <gtk/gtkmain.h>
 
 #include <sys/types.h>
@@ -28,6 +29,10 @@
 #include <time.h>
 #include <string.h>
 
+#ifdef WITH_BONOBO
+#include <bonobo/bonobo-main.h>
+#endif
+
 static int gnumeric_show_version = FALSE;
 static char *dump_file_name = NULL;
 
@@ -150,7 +155,8 @@ main (int argc, char *argv [])
 	if (startup_files) {
 		int i;
 		for (i = 0; startup_files [i]  && !initial_workbook_open_complete ; i++) {
- 			if (wb_view_open (startup_files[i], wbc, TRUE, NULL))
+ 			if (gui_file_read (WORKBOOK_CONTROL_GUI (wbc),
+					   startup_files[i], NULL))
   				opened_workbook = TRUE;
 
 			/* cheesy attempt to keep the ui from freezing during load */
