@@ -34,6 +34,7 @@
  *    Almer S. Tigelaar (almer@gnome.org)
  */
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include "gnumeric.h"
 #include "number-match.h"
 #include "expr.h"
@@ -53,7 +54,6 @@
 #include <string.h>
 #include <errno.h>
 #include <stdlib.h>
-#include <libgnome/gnome-i18n.h>
 
 #define YYDEBUG 1
 /* ------------------------------------------------------------------------- */
