@@ -4,7 +4,7 @@
  * position.c: Utility routines for various types of positional
  *         coordinates.
  *
- * Copyright (C) 2000 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2000-2002 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -30,6 +30,18 @@
 #include "value.h"
 #include "ranges.h"
 
+
+CellRef *
+cellref_set (CellRef *ref, Sheet *sheet, int col, int row, gboolean relative)
+{
+	ref->sheet = sheet;
+	ref->col   = col;
+	ref->row   = row;
+	ref->col_relative = ref->row_relative = relative;
+
+	return ref;
+}
+
 EvalPos *
 eval_pos_init (EvalPos *ep, Sheet *sheet, CellPos const *pos)
 {
@@ -139,7 +151,6 @@ parse_pos_init_dep (ParsePos *pp, Dependent const *dep)
 ParsePos *
 parse_pos_init_cell (ParsePos *pp, Cell const *cell)
 {
-	g_return_val_if_fail (pp != NULL, NULL);
 	g_return_val_if_fail (cell != NULL, NULL);
 	g_return_val_if_fail (IS_SHEET (cell->base.sheet), NULL);
 	g_return_val_if_fail (cell->base.sheet->workbook != NULL, NULL);
@@ -151,20 +162,30 @@ parse_pos_init_cell (ParsePos *pp, Cell const *cell)
 ParsePos *
 parse_pos_init_evalpos (ParsePos *pp, EvalPos const *ep)
 {
-	g_return_val_if_fail (pp != NULL, NULL);
 	g_return_val_if_fail (ep != NULL, NULL);
 
 	return parse_pos_init (pp, NULL, ep->sheet, ep->eval.col, ep->eval.row);
 }
 
+ParsePos *
+parse_pos_init_editpos (ParsePos *pp, SheetView const *sv)
+{
+	g_return_val_if_fail (IS_SHEET_VIEW (sv), NULL);
+
+	return parse_pos_init (pp, NULL, sv_sheet (sv),
+		sv->edit_pos.col, sv->edit_pos.row);
+}
+
+/********************************************************************************/
+
 gboolean
 cellref_equal (CellRef const *a, CellRef const *b)
 {
-	return	(a->col_relative == b->col_relative) &&
-		(a->row_relative == b->row_relative) &&
-		(a->col == b->col) &&
-		(a->row == b->row) &&
-		(a->sheet == b->sheet);
+	return (a->col == b->col) &&
+	       (a->col_relative == b->col_relative) &&
+	       (a->row == b->row) &&
+	       (a->row_relative == b->row_relative) &&
+	       (a->sheet == b->sheet);
 }
 
 int
@@ -243,3 +264,47 @@ cellref_make_abs (CellRef *dest, CellRef const *src, EvalPos const *ep)
 	dest->row_relative = dest->col_relative = FALSE;
 }
 
+
+guint
+cellref_hash (const CellRef *cr)
+{
+	guint h = ((cr->col * 5) ^ cr->row) * 4;
+	if (cr->col_relative) h |= 1;
+	if (cr->row_relative) h |= 2;
+	return h;
+}
+
+RangeRef *value_to_rangeref    (Value *v, gboolean release)
+{
+	RangeRef *gr;
+
+	g_return_val_if_fail (v->type == VALUE_CELLRANGE, NULL);
+
+	gr = g_new0 (RangeRef, 1);
+	*gr = v->v_range.cell;
+
+	if (release)
+		value_release (v);
+	
+	return gr;
+	
+}
+
+/**
+ * range_ref_normalize :  Take a range_ref and normalize it
+ *     by converting to absolute coords and handling inversions.
+ */
+void
+rangeref_normalize (EvalPos const *ep, RangeRef const *ref,
+		    Sheet **start_sheet, Sheet **end_sheet, Range *dest)
+{
+	g_return_if_fail (ref != NULL);
+	g_return_if_fail (ep != NULL);
+
+	cellref_get_abs_pos (&ref->a, &ep->eval, &dest->start);
+	cellref_get_abs_pos (&ref->b, &ep->eval, &dest->end);
+	range_normalize (dest);
+
+	*start_sheet = eval_sheet (ref->a.sheet, ep->sheet);
+	*end_sheet = eval_sheet (ref->b.sheet, ep->sheet);
+}
