@@ -7,6 +7,7 @@
  * Handles printing of Sheets.
  */
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include "gnumeric.h"
 #include "print.h"
 
@@ -29,15 +30,12 @@
 #include "ranges.h"
 #include "style.h"
 
-#include <libgnome/gnome-i18n.h>
 #include <libgnomeprint/gnome-print-master.h>
 #include <libgnomeprint/gnome-print-config.h>
 #include <libgnomeprintui/gnome-print-master-preview.h>
 #include <libgnomeprintui/gnome-print-dialog.h>
 #include <libgnomeprintui/gnome-printer-dialog.h>
 
-extern int print_debugging;
-
 /*
  * Margins
  *
@@ -296,7 +294,7 @@ print_hf_element (PrintJobInfo const *pj, char const *format,
 		return;
 	}
 
-	len = get_width_string (pj->decoration_font, text);
+	len = gnome_font_get_width_utf8 (pj->decoration_font, text);
 
 	print_info_get_margins   (pj->pi, &header, &footer, &left, &right);	
 	switch (side){
@@ -316,7 +314,7 @@ print_hf_element (PrintJobInfo const *pj, char const *format,
 		x = 0;
 	}
 	gnome_print_moveto (pj->print_context, x, y);
-	print_show (pj->print_context, text);
+	gnome_print_show (pj->print_context, text);
 	g_free (text);
 }
 
