@@ -29,8 +29,8 @@ void	 sheet_style_set_range		(Sheet  *sheet, Range const *range,
 void	 sheet_style_set_pos		(Sheet  *sheet, int col, int row,
 					 MStyle *mstyle);
 
-void	 sheet_style_insert_colrow	(ExprRelocateInfo const *rinfo);
-void	 sheet_style_relocate		(ExprRelocateInfo const *rinfo);
+void	 sheet_style_insert_colrow	(GnmExprRelocateInfo const *rinfo);
+void	 sheet_style_relocate		(GnmExprRelocateInfo const *rinfo);
 void	 sheet_style_get_uniform	(Sheet const *sheet, Range const *r,
 					 MStyle **style, StyleBorder **borders);
 void	 sheet_style_get_extent		(Sheet const *sheet, Range *r);
@@ -40,6 +40,9 @@ void     style_row_init			(StyleBorder const * * *prev_vert,
 					 int start_col, int end_col,
 					 gpointer mem, gboolean hide_grid);
 MStyle  *sheet_style_most_common_in_col (Sheet const *sheet, int col);
+void	 sheet_style_foreach	   	(Sheet const *sheet,
+					 GHFunc	    func,
+					 gpointer    user_data);
 
 void sheet_style_init     (Sheet *sheet);
 void sheet_style_shutdown (Sheet *sheet);
