@@ -18,6 +18,7 @@ struct _Sheet {
 
 	char        *name_quoted;
 	char        *name_unquoted;
+	char        *name_unquoted_collate_key;
 
 	SheetStyleData *style_data; /* See sheet-style.c */
 
@@ -48,8 +49,12 @@ struct _Sheet {
 	gboolean    outline_symbols_below;
 	gboolean    outline_symbols_right;
 
+	gboolean    has_hidden_rows;  /* Filtered or hidden rows */
+
         SolverParameters *solver_parameters;
 
+	gint simulation_round;
+
 	GnmDepContainer *deps;
 
 	GSList		 *list_merged;
