@@ -178,7 +178,9 @@ sort_permute (WorkbookControl *context, SortData *data, const int *perm, int len
 	PasteTarget pt;
 
 	pt.sheet = data->sheet;
-	pt.paste_flags = PASTE_FORMATS | PASTE_CONTENT;
+	pt.paste_flags = PASTE_CONTENT;
+	if (!data->retain_formats)
+		pt.paste_flags = pt.paste_flags | PASTE_FORMATS;
 
 #ifdef DEBUG_SORT
 	fprintf (stderr, "Permutation:");
