@@ -16,6 +16,7 @@ typedef enum {
   TdistDistribution, LogarithmicDistribution, LogisticDistribution,
   ParetoDistribution, LognormalDistribution, RayleighDistribution,
   LevyDistribution, ExponentialPowerDistribution, RayleighTailDistribution,
+  LandauDistribution, GaussianTailDistribution, UniformIntDistribution,
   /* PatternedDistribution, */ NegativeBinomialDistribution, ExponentialDistribution
 } random_distribution_t;
 
@@ -128,6 +129,11 @@ typedef struct {
         gnum_float a;
 } laplace_random_tool_t;
 
+typedef struct {
+        gnum_float a;
+        gnum_float sigma;
+} gaussian_tail_random_tool_t;
+
 typedef struct {
         gnum_float a;
         gnum_float b;
@@ -170,6 +176,7 @@ typedef union {
         geometric_random_tool_t     geometric;
         gumbel_random_tool_t        gumbel;
         laplace_random_tool_t       laplace;
+        gaussian_tail_random_tool_t gaussian_tail;
         weibull_random_tool_t       weibull;
 /*         patterned_random_tool_t   patterned; */
 } random_tool_t;
