@@ -1,3 +1,4 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * reports.c:  Solver report generation.
  *
@@ -22,6 +23,7 @@
 */
 
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include "gnumeric.h"
 #include "numbers.h"
 #include "reports-write.h"
@@ -44,7 +46,6 @@
 #include <math.h>
 #include <stdlib.h>
 #include <stdio.h>
-#include <libgnome/gnome-i18n.h>
 #include <sys/utsname.h>
 #include <string.h>
 
