@@ -1,3 +1,4 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * solver.c:  The Solver's core system.
  *
@@ -22,6 +23,7 @@
 */
 
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include "reports.h"
 
 #include "parse-util.h"
@@ -43,7 +45,6 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <sys/times.h>
-#include <libgnome/gnome-i18n.h>
 
 /* ------------------------------------------------------------------------- */
 
@@ -55,11 +56,7 @@ solver_param_new (void)
 
 	res->options.model_type          = SolverLPModel;
 	res->options.assume_non_negative = TRUE;
-#if __HAVE_GLPK__
 	res->options.algorithm           = GLPKSimplex;
-#else
-	res->options.algorithm           = LPSolve;
-#endif
 	res->input_entry_str             = g_strdup ("");
 	res->problem_type                = SolverMaximize;
 	res->constraints                 = NULL;
@@ -490,10 +487,6 @@ lp_qp_solver_init (Sheet *sheet, const SolverParameters *param,
 		res->ilp_flag = TRUE;
 	}
 
-#if 0
-	alg->print_fn (program);
-#endif
-
 	return program;
 }
 
