@@ -4,6 +4,9 @@
  *
  * Copyright (C) Jody Goldberg <jody@gnome.org>
  *
+ * based on work by
+ *	 Almer S. Tigelaar <almer@gnome.org>
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -20,6 +23,7 @@
  */
 
 #include <gnumeric-config.h>
+#include <gnumeric-i18n.h>
 #include "gnumeric.h"
 #include "numbers.h"
 #include "mathfunc.h"
@@ -33,7 +37,6 @@
 #include "workbook-control.h"
 #include "parse-util.h"
 
-#include <libgnome/gnome-i18n.h>
 #include <math.h>
 #include <string.h>
 
@@ -246,7 +249,7 @@ validation_eval (WorkbookControl *wbc, MStyle const *mstyle,
 			gboolean  dummy, valid;
 
 			val = gnm_expr_eval (expr, eval_pos_init_cell (&ep, cell),
-					 GNM_EXPR_EVAL_STRICT);
+					     GNM_EXPR_EVAL_STRICT);
 			valid = value_get_as_bool (val, &dummy);
 			value_release (val);
 
@@ -261,6 +264,7 @@ validation_eval (WorkbookControl *wbc, MStyle const *mstyle,
 				g_return_val_if_fail (v->expr[1] != NULL, VALIDATION_STATUS_VALID);
 
 				gnm_expr_ref (v->expr[1]);
+				gnm_expr_unref (expr);
 				expr = gnm_expr_new_binary (val_expr,
 					(v->op == VALIDATION_OP_BETWEEN) ? GNM_EXPR_OP_LTE : GNM_EXPR_OP_GT,
 					v->expr[1]);
@@ -277,6 +281,7 @@ validation_eval (WorkbookControl *wbc, MStyle const *mstyle,
 				parse_pos_init_evalpos (&pp, &ep));
 			msg = g_strdup_printf (_("%s is not true."), expr_str);
 			g_free (expr_str);
+			gnm_expr_unref (expr);
 		}
 	}
 
