@@ -85,7 +85,8 @@ gboolean    workbook_sheet_reorganize    (WorkbookControl *wbc,
 					  GSList *changed_names, GSList *new_order,  
 					  GSList *new_names,  GSList *old_names,
 					  GSList **new_sheets, GSList *color_changed,
-					  GSList *colors_fore, GSList *colors_back);
+					  GSList *colors_fore, GSList *colors_back,
+					  GSList *protection_changed, GSList *new_locks);
 
 /* IO Routines */
 gboolean       workbook_set_filename   (Workbook *wb, const gchar *);
@@ -106,9 +107,9 @@ void        workbook_add_summary_info    (Workbook *wb, SummaryItem *sit);
 /* See also sheet_cell_foreach_range */
 Value	   *workbook_foreach_cell_in_range (EvalPos const *pos,
 					    Value const	  *cell_range,
-					    gboolean	   only_existing,
-					    ForeachCellCB  handler,
-					    void	  *closure);
+					    CellIterFlags  flags,
+					    CellIterFunc   handler,
+					    gpointer	   closure);
 GPtrArray  *workbook_cells               (Workbook *wb, gboolean comments);
 
 /* Calculation */
